"""
Python module generated from Java source file com.google.common.collect.ForwardingMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Iterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingMultiset(ForwardingCollection, Multiset):
    """
    A multiset which forwards all its method calls to another multiset. Subclasses should override
    one or more methods to modify the behavior of the backing multiset as desired per the <a
    href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **Warning:** The methods of `ForwardingMultiset` forward **indiscriminately** to
    the methods of the delegate. For example, overriding .add(Object, int) alone **will
    not** change the behavior of .add(Object), which can lead to unexpected behavior. In
    this case, you should override `add(Object)` as well, either providing your own
    implementation, or delegating to the provided `standardAdd` method.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingMultiset`.
    
    The `standard` methods and any collection views they return are not guaranteed to be
    thread-safe, even when all of the methods that they depend on are thread-safe.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0
    """

    def count(self, element: "Object") -> int:
        ...


    def add(self, element: "E", occurrences: int) -> int:
        ...


    def remove(self, element: "Object", occurrences: int) -> int:
        ...


    def elementSet(self) -> set["E"]:
        ...


    def entrySet(self) -> set["Entry"["E"]]:
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def setCount(self, element: "E", count: int) -> int:
        ...


    def setCount(self, element: "E", oldCount: int, newCount: int) -> bool:
        ...



"""
Python module generated from Java source file java.util.concurrent.ExecutionException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent import *
from typing import Any, Callable, Iterable, Tuple


class ExecutionException(Exception):
    """
    Exception thrown when attempting to retrieve the result of a task
    that aborted by throwing an exception. This exception can be
    inspected using the .getCause() method.

    Author(s)
    - Doug Lea

    See
    - Future

    Since
    - 1.5
    """

    def __init__(self, message: str, cause: "Throwable"):
        """
        Constructs an `ExecutionException` with the specified detail
        message and cause.

        Arguments
        - message: the detail message
        - cause: the cause (which is saved for later retrieval by the
                .getCause() method)
        """
        ...


    def __init__(self, cause: "Throwable"):
        """
        Constructs an `ExecutionException` with the specified cause.
        The detail message is set to `(cause == null ? null :
        cause.toString())` (which typically contains the class and
        detail message of `cause`).

        Arguments
        - cause: the cause (which is saved for later retrieval by the
                .getCause() method)
        """
        ...



"""
Python module generated from Java source file org.bukkit.material.Attachable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Attachable(Directional):
    """
    Indicates that a block can be attached to another block
    """

    def getAttachedFace(self) -> "BlockFace":
        """
        Gets the face that this block is attached on

        Returns
        - BlockFace attached to
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.ShieldMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import DyeColor
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class ShieldMeta(BannerMeta):

    def getBaseColor(self) -> "DyeColor":
        """
        Gets the base color for this shield.

        Returns
        - the base color or null
        """
        ...


    def setBaseColor(self, color: "DyeColor") -> None:
        """
        Sets the base color for this shield.
        
        **Note:** If the shield contains a
        org.bukkit.block.banner.Pattern, then a null base color will
        retain the pattern but default the base color to DyeColor.WHITE.

        Arguments
        - color: the base color or null
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.Lidded

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class Lidded:

    def open(self) -> None:
        """
        Sets the block's animated state to open and prevents it from being closed
        until .close() is called.
        """
        ...


    def close(self) -> None:
        """
        Sets the block's animated state to closed even if a player is currently
        viewing this block.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.StandardTable

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Function
from com.google.common.base import Predicate
from com.google.common.base import Supplier
from com.google.common.collect import *
from com.google.common.collect.Maps import IteratorBasedAbstractMap
from com.google.common.collect.Maps import ViewCachingAbstractMap
from com.google.common.collect.Sets import ImprovedAbstractSet
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import WeakOuter
from java.io import Serializable
from java.util import Iterator
from java.util import Spliterator
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class StandardTable(AbstractTable, Serializable):
    """
    Table implementation backed by a map that associates row keys with column key / value
    secondary maps. This class provides rapid access to records by the row key alone or by both keys,
    but not by just the column key.
    
    The views returned by .column, .columnKeySet(), and .columnMap() have
    iterators that don't support `remove()`. Otherwise, all optional operations are supported.
    Null row keys, columns keys, and values are not supported.
    
    Lookups by row key are often faster than lookups by column key, because the data is stored in
    a `Map<R, Map<C, V>>`. A method call like `column(columnKey).get(rowKey)` still runs
    quickly, since the row key is provided. However, `column(columnKey).size()` takes longer,
    since an iteration across all row keys occurs.
    
    Note that this implementation is not synchronized. If multiple threads access this table
    concurrently and one of the threads modifies the table, it must be synchronized externally.

    Author(s)
    - Jared Levy
    """

    def contains(self, rowKey: "Object", columnKey: "Object") -> bool:
        ...


    def containsColumn(self, columnKey: "Object") -> bool:
        ...


    def containsRow(self, rowKey: "Object") -> bool:
        ...


    def containsValue(self, value: "Object") -> bool:
        ...


    def get(self, rowKey: "Object", columnKey: "Object") -> "V":
        ...


    def isEmpty(self) -> bool:
        ...


    def size(self) -> int:
        ...


    def clear(self) -> None:
        ...


    def put(self, rowKey: "R", columnKey: "C", value: "V") -> "V":
        ...


    def remove(self, rowKey: "Object", columnKey: "Object") -> "V":
        ...


    def cellSet(self) -> set["Cell"["R", "C", "V"]]:
        """
        
        
        The set's iterator traverses the mappings for the first row, the mappings for the second
        row, and so on.
        
        Each cell is an immutable snapshot of a row key / column key / value mapping, taken at the
        time the cell is returned by a method call to the set or its iterator.
        """
        ...


    def row(self, rowKey: "R") -> dict["C", "V"]:
        ...


    def column(self, columnKey: "C") -> dict["R", "V"]:
        """
        
        
        The returned map's views have iterators that don't support `remove()`.
        """
        ...


    def rowKeySet(self) -> set["R"]:
        ...


    def columnKeySet(self) -> set["C"]:
        """
        
        
        The returned set has an iterator that does not support `remove()`.
        
        The set's iterator traverses the columns of the first row, the columns of the second row,
        etc., skipping any columns that have appeared previously.
        """
        ...


    def values(self) -> Iterable["V"]:
        """
        
        
        The collection's iterator traverses the values for the first row, the values for the second
        row, and so on.
        """
        ...


    def rowMap(self) -> dict["R", dict["C", "V"]]:
        ...


    def columnMap(self) -> dict["C", dict["R", "V"]]:
        ...



"""
Python module generated from Java source file java.text.SimpleDateFormat

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.text import *
from java.util import Calendar
from java.util import Date
from java.util import GregorianCalendar
from java.util import Locale
from java.util import SimpleTimeZone
from java.util import SortedMap
from java.util import TimeZone
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from sun.util.calendar import CalendarUtils
from sun.util.calendar import ZoneInfoFile
from sun.util.locale.provider import LocaleProviderAdapter
from sun.util.locale.provider import TimeZoneNameUtility
from typing import Any, Callable, Iterable, Tuple


class SimpleDateFormat(DateFormat):
    """
    `SimpleDateFormat` is a concrete class for formatting and
    parsing dates in a locale-sensitive manner. It allows for formatting
    (date &rarr; text), parsing (text &rarr; date), and normalization.
    
    
    `SimpleDateFormat` allows you to start by choosing
    any user-defined patterns for date-time formatting. However, you
    are encouraged to create a date-time formatter with either
    `getTimeInstance`, `getDateInstance`, or
    `getDateTimeInstance` in `DateFormat`. Each
    of these class methods can return a date/time formatter initialized
    with a default format pattern. You may modify the format pattern
    using the `applyPattern` methods as desired.
    For more information on using these methods, see
    DateFormat.
    
    <h2>Date and Time Patterns</h2>
    
    Date and time formats are specified by *date and time pattern*
    strings.
    Within date and time pattern strings, unquoted letters from
    `'A'` to `'Z'` and from `'a'` to
    `'z'` are interpreted as pattern letters representing the
    components of a date or time string.
    Text can be quoted using single quotes (`'`) to avoid
    interpretation.
    `"''"` represents a single quote.
    All other characters are not interpreted; they're simply copied into the
    output string during formatting or matched against the input string
    during parsing.
    
    The following pattern letters are defined (all other characters from
    `'A'` to `'Z'` and from `'a'` to
    `'z'` are reserved):
    <blockquote>
    <table class="striped">
    <caption style="display:none">Chart shows pattern letters, date/time component, presentation, and examples.</caption>
    <thead>
        <tr>
            <th scope="col" style="text-align:left">Letter
            <th scope="col" style="text-align:left">Date or Time Component
            <th scope="col" style="text-align:left">Presentation
            <th scope="col" style="text-align:left">Examples
    </thead>
    <tbody>
        <tr>
            <th scope="row">`G`
            <td>Era designator
            <td><a href="#text">Text</a>
            <td>`AD`
        <tr>
            <th scope="row">`y`
            <td>Year
            <td><a href="#year">Year</a>
            <td>`1996`; `96`
        <tr>
            <th scope="row">`Y`
            <td>Week year
            <td><a href="#year">Year</a>
            <td>`2009`; `09`
        <tr>
            <th scope="row">`M`
            <td>Month in year (context sensitive)
            <td><a href="#month">Month</a>
            <td>`July`; `Jul`; `07`
        <tr>
            <th scope="row">`L`
            <td>Month in year (standalone form)
            <td><a href="#month">Month</a>
            <td>`July`; `Jul`; `07`
        <tr>
            <th scope="row">`w`
            <td>Week in year
            <td><a href="#number">Number</a>
            <td>`27`
        <tr>
            <th scope="row">`W`
            <td>Week in month
            <td><a href="#number">Number</a>
            <td>`2`
        <tr>
            <th scope="row">`D`
            <td>Day in year
            <td><a href="#number">Number</a>
            <td>`189`
        <tr>
            <th scope="row">`d`
            <td>Day in month
            <td><a href="#number">Number</a>
            <td>`10`
        <tr>
            <th scope="row">`F`
            <td>Day of week in month
            <td><a href="#number">Number</a>
            <td>`2`
        <tr>
            <th scope="row">`E`
            <td>Day name in week
            <td><a href="#text">Text</a>
            <td>`Tuesday`; `Tue`
        <tr>
            <th scope="row">`u`
            <td>Day number of week (1 = Monday, ..., 7 = Sunday)
            <td><a href="#number">Number</a>
            <td>`1`
        <tr>
            <th scope="row">`a`
            <td>Am/pm marker
            <td><a href="#text">Text</a>
            <td>`PM`
        <tr>
            <th scope="row">`H`
            <td>Hour in day (0-23)
            <td><a href="#number">Number</a>
            <td>`0`
        <tr>
            <th scope="row">`k`
            <td>Hour in day (1-24)
            <td><a href="#number">Number</a>
            <td>`24`
        <tr>
            <th scope="row">`K`
            <td>Hour in am/pm (0-11)
            <td><a href="#number">Number</a>
            <td>`0`
        <tr>
            <th scope="row">`h`
            <td>Hour in am/pm (1-12)
            <td><a href="#number">Number</a>
            <td>`12`
        <tr>
            <th scope="row">`m`
            <td>Minute in hour
            <td><a href="#number">Number</a>
            <td>`30`
        <tr>
            <th scope="row">`s`
            <td>Second in minute
            <td><a href="#number">Number</a>
            <td>`55`
        <tr>
            <th scope="row">`S`
            <td>Millisecond
            <td><a href="#number">Number</a>
            <td>`978`
        <tr>
            <th scope="row">`z`
            <td>Time zone
            <td><a href="#timezone">General time zone</a>
            <td>`Pacific Standard Time`; `PST`; `GMT-08:00`
        <tr>
            <th scope="row">`Z`
            <td>Time zone
            <td><a href="#rfc822timezone">RFC 822 time zone</a>
            <td>`-0800`
        <tr>
            <th scope="row">`X`
            <td>Time zone
            <td><a href="#iso8601timezone">ISO 8601 time zone</a>
            <td>`-08`; `-0800`;  `-08:00`
    </tbody>
    </table>
    </blockquote>
    Pattern letters are usually repeated, as their number determines the
    exact presentation:
    
    - <strong><a id="text">Text:</a></strong>
        For formatting, if the number of pattern letters is 4 or more,
        the full form is used; otherwise a short or abbreviated form
        is used if available.
        For parsing, both forms are accepted, independent of the number
        of pattern letters.
    - <strong><a id="number">Number:</a></strong>
        For formatting, the number of pattern letters is the minimum
        number of digits, and shorter numbers are zero-padded to this amount.
        For parsing, the number of pattern letters is ignored unless
        it's needed to separate two adjacent fields.
    - <strong><a id="year">Year:</a></strong>
        If the formatter's .getCalendar() Calendar is the Gregorian
        calendar, the following rules are applied.
        
        - For formatting, if the number of pattern letters is 2, the year
            is truncated to 2 digits; otherwise it is interpreted as a
            <a href="#number">number</a>.
        - For parsing, if the number of pattern letters is more than 2,
            the year is interpreted literally, regardless of the number of
            digits. So using the pattern "MM/dd/yyyy", "01/11/12" parses to
            Jan 11, 12 A.D.
        - For parsing with the abbreviated year pattern ("y" or "yy"),
            `SimpleDateFormat` must interpret the abbreviated year
            relative to some century.  It does this by adjusting dates to be
            within 80 years before and 20 years after the time the `SimpleDateFormat`
            instance is created. For example, using a pattern of "MM/dd/yy" and a
            `SimpleDateFormat` instance created on Jan 1, 1997,  the string
            "01/11/12" would be interpreted as Jan 11, 2012 while the string "05/04/64"
            would be interpreted as May 4, 1964.
            During parsing, only strings consisting of exactly two digits, as defined by
            Character.isDigit(char), will be parsed into the default century.
            Any other numeric string, such as a one digit string, a three or more digit
            string, or a two digit string that isn't all digits (for example, "-1"), is
            interpreted literally.  So "01/02/3" or "01/02/003" are parsed, using the
            same pattern, as Jan 2, 3 AD.  Likewise, "01/02/-3" is parsed as Jan 2, 4 BC.
        
        Otherwise, calendar system specific forms are applied.
        For both formatting and parsing, if the number of pattern
        letters is 4 or more, a calendar specific Calendar.LONG long form is used. Otherwise, a calendar
        specific Calendar.SHORT short or abbreviated form
        is used.
        
        If week year `'Y'` is specified and the .getCalendar() calendar doesn't support any <a
        href="../util/GregorianCalendar.html#week_year"> week
        years</a>, the calendar year (`'y'`) is used instead. The
        support of week years can be tested with a call to DateFormat.getCalendar() getCalendar().java.util.Calendar.isWeekDateSupported()
        isWeekDateSupported().
    - <strong><a id="month">Month:</a></strong>
        If the number of pattern letters is 3 or more, the month is
        interpreted as <a href="#text">text</a>; otherwise,
        it is interpreted as a <a href="#number">number</a>.
        
        - Letter *M* produces context-sensitive month names, such as the
            embedded form of names. Letter *M* is context-sensitive in the
            sense that when it is used in the standalone pattern, for example,
            "MMMM", it gives the standalone form of a month name and when it is
            used in the pattern containing other field(s), for example, "d MMMM",
            it gives the format form of a month name. For example, January in the
            Catalan language is "de gener" in the format form while it is "gener"
            in the standalone form. In this case, "MMMM" will produce "gener" and
            the month part of the "d MMMM" will produce "de gener". If a
            `DateFormatSymbols` has been set explicitly with constructor
            .SimpleDateFormat(String,DateFormatSymbols) or method .setDateFormatSymbols(DateFormatSymbols), the month names given by
            the `DateFormatSymbols` are used.
        - Letter *L* produces the standalone form of month names.
        
        
    - <strong><a id="timezone">General time zone:</a></strong>
        Time zones are interpreted as <a href="#text">text</a> if they have
        names. For time zones representing a GMT offset value, the
        following syntax is used:
        ```
        <a id="GMTOffsetTimeZone">*GMTOffsetTimeZone:*</a>
                `GMT` *Sign* *Hours* `:` *Minutes*
        *Sign:* one of
                `+ -`
        *Hours:*
                *Digit*
                *Digit* *Digit*
        *Minutes:*
                *Digit* *Digit*
        *Digit:* one of
                `0 1 2 3 4 5 6 7 8 9````
        *Hours* must be between 0 and 23, and *Minutes* must be between
        00 and 59. The format is locale independent and digits must be taken
        from the Basic Latin block of the Unicode standard.
        For parsing, <a href="#rfc822timezone">RFC 822 time zones</a> are also
        accepted.
    - <strong><a id="rfc822timezone">RFC 822 time zone:</a></strong>
        For formatting, the RFC 822 4-digit time zone format is used:
    
        ```
        *RFC822TimeZone:*
                *Sign* *TwoDigitHours* *Minutes*
        *TwoDigitHours:*
                *Digit Digit*```
        *TwoDigitHours* must be between 00 and 23. Other definitions
        are as for <a href="#timezone">general time zones</a>.
    
        For parsing, <a href="#timezone">general time zones</a> are also
        accepted.
    - <strong><a id="iso8601timezone">ISO 8601 Time zone:</a></strong>
        The number of pattern letters designates the format for both formatting
        and parsing as follows:
        ```
        *ISO8601TimeZone:*
                *OneLetterISO8601TimeZone*
                *TwoLetterISO8601TimeZone*
                *ThreeLetterISO8601TimeZone*
        *OneLetterISO8601TimeZone:*
                *Sign* *TwoDigitHours*
                `Z`
        *TwoLetterISO8601TimeZone:*
                *Sign* *TwoDigitHours* *Minutes*
                `Z`
        *ThreeLetterISO8601TimeZone:*
                *Sign* *TwoDigitHours* `:` *Minutes*
                `Z````
        Other definitions are as for <a href="#timezone">general time zones</a> or
        <a href="#rfc822timezone">RFC 822 time zones</a>.
    
        For formatting, if the offset value from GMT is 0, `"Z"` is
        produced. If the number of pattern letters is 1, any fraction of an hour
        is ignored. For example, if the pattern is `"X"` and the time zone is
        `"GMT+05:30"`, `"+05"` is produced.
    
        For parsing, `"Z"` is parsed as the UTC time zone designator.
        <a href="#timezone">General time zones</a> are *not* accepted.
    
        If the number of pattern letters is 4 or more, IllegalArgumentException is thrown when constructing a `SimpleDateFormat` or .applyPattern(String) applying a
        pattern.
    
    `SimpleDateFormat` also supports *localized date and time
    pattern* strings. In these strings, the pattern letters described above
    may be replaced with other, locale dependent, pattern letters.
    `SimpleDateFormat` does not deal with the localization of text
    other than the pattern letters; that's up to the client of the class.
    
    <h3>Examples</h3>
    
    The following examples show how date and time patterns are interpreted in
    the U.S. locale. The given date and time are 2001-07-04 12:08:56 local time
    in the U.S. Pacific Time time zone.
    <blockquote>
    <table class="striped">
    <caption style="display:none">Examples of date and time patterns interpreted in the U.S. locale</caption>
    <thead>
        <tr>
            <th scope="col" style="text-align:left">Date and Time Pattern
            <th scope="col" style="text-align:left">Result
    </thead>
    <tbody>
        <tr>
            <th scope="row">`"yyyy.MM.dd G 'at' HH:mm:ss z"`
            <td>`2001.07.04 AD at 12:08:56 PDT`
        <tr>
            <th scope="row">`"EEE, MMM d, ''yy"`
            <td>`Wed, Jul 4, '01`
        <tr>
            <th scope="row">`"h:mm a"`
            <td>`12:08 PM`
        <tr>
            <th scope="row">`"hh 'o''clock' a, zzzz"`
            <td>`12 o'clock PM, Pacific Daylight Time`
        <tr>
            <th scope="row">`"K:mm a, z"`
            <td>`0:08 PM, PDT`
        <tr>
            <th scope="row">`"yyyyy.MMMMM.dd GGG hh:mm aaa"`
            <td>`02001.July.04 AD 12:08 PM`
        <tr>
            <th scope="row">`"EEE, d MMM yyyy HH:mm:ss Z"`
            <td>`Wed, 4 Jul 2001 12:08:56 -0700`
        <tr>
            <th scope="row">`"yyMMddHHmmssZ"`
            <td>`010704120856-0700`
        <tr>
            <th scope="row">`"yyyy-MM-dd'T'HH:mm:ss.SSSZ"`
            <td>`2001-07-04T12:08:56.235-0700`
        <tr>
            <th scope="row">`"yyyy-MM-dd'T'HH:mm:ss.SSSXXX"`
            <td>`2001-07-04T12:08:56.235-07:00`
        <tr>
            <th scope="row">`"YYYY-'W'ww-u"`
            <td>`2001-W27-3`
    </tbody>
    </table>
    </blockquote>
    
    <h3><a id="synchronization">Synchronization</a></h3>
    
    
    Date formats are not synchronized.
    It is recommended to create separate format instances for each thread.
    If multiple threads access a format concurrently, it must be synchronized
    externally.

    Author(s)
    - Mark Davis, Chen-Lieh Huang, Alan Liu

    See
    - java.time.format.DateTimeFormatter

    Since
    - 1.1

    Unknown Tags
    - Consider using java.time.format.DateTimeFormatter as an
    immutable and thread-safe alternative.
    """

    def __init__(self):
        """
        Constructs a `SimpleDateFormat` using the default pattern and
        date format symbols for the default
        java.util.Locale.Category.FORMAT FORMAT locale.
        **Note:** This constructor may not support all locales.
        For full coverage, use the factory methods in the DateFormat
        class.
        """
        ...


    def __init__(self, pattern: str):
        """
        Constructs a `SimpleDateFormat` using the given pattern and
        the default date format symbols for the default
        java.util.Locale.Category.FORMAT FORMAT locale.
        **Note:** This constructor may not support all locales.
        For full coverage, use the factory methods in the DateFormat
        class.
        This is equivalent to calling
        .SimpleDateFormat(String, Locale)
            SimpleDateFormat(pattern, Locale.getDefault(Locale.Category.FORMAT)).

        Arguments
        - pattern: the pattern describing the date and time format

        Raises
        - NullPointerException: if the given pattern is null
        - IllegalArgumentException: if the given pattern is invalid

        See
        - java.util.Locale.Category.FORMAT
        """
        ...


    def __init__(self, pattern: str, locale: "Locale"):
        """
        Constructs a `SimpleDateFormat` using the given pattern and
        the default date format symbols for the given locale.
        **Note:** This constructor may not support all locales.
        For full coverage, use the factory methods in the DateFormat
        class.

        Arguments
        - pattern: the pattern describing the date and time format
        - locale: the locale whose date format symbols should be used

        Raises
        - NullPointerException: if the given pattern or locale is null
        - IllegalArgumentException: if the given pattern is invalid
        """
        ...


    def __init__(self, pattern: str, formatSymbols: "DateFormatSymbols"):
        """
        Constructs a `SimpleDateFormat` using the given pattern and
        date format symbols.

        Arguments
        - pattern: the pattern describing the date and time format
        - formatSymbols: the date format symbols to be used for formatting

        Raises
        - NullPointerException: if the given pattern or formatSymbols is null
        - IllegalArgumentException: if the given pattern is invalid
        """
        ...


    def set2DigitYearStart(self, startDate: "Date") -> None:
        """
        Sets the 100-year period 2-digit years will be interpreted as being in
        to begin on the date the user specifies.

        Arguments
        - startDate: During parsing, two digit years will be placed in the range
        `startDate` to `startDate + 100 years`.

        Raises
        - NullPointerException: if `startDate` is `null`.

        See
        - .get2DigitYearStart

        Since
        - 1.2
        """
        ...


    def get2DigitYearStart(self) -> "Date":
        """
        Returns the beginning date of the 100-year period 2-digit years are interpreted
        as being within.

        Returns
        - the start of the 100-year period into which two digit years are
        parsed

        See
        - .set2DigitYearStart

        Since
        - 1.2
        """
        ...


    def format(self, date: "Date", toAppendTo: "StringBuffer", pos: "FieldPosition") -> "StringBuffer":
        """
        Formats the given `Date` into a date/time string and appends
        the result to the given `StringBuffer`.

        Arguments
        - date: the date-time value to be formatted into a date-time string.
        - toAppendTo: where the new date-time text is to be appended.
        - pos: keeps track on the position of the field within
        the returned string. For example, given a date-time text
        `"1996.07.10 AD at 15:08:56 PDT"`, if the given `fieldPosition`
        is DateFormat.YEAR_FIELD, the begin index and end index of
        `fieldPosition` will be set to 0 and 4, respectively.
        Notice that if the same date-time field appears more than once in a
        pattern, the `fieldPosition` will be set for the first occurrence
        of that date-time field. For instance, formatting a `Date` to the
        date-time string `"1 PM PDT (Pacific Daylight Time)"` using the
        pattern `"h a z (zzzz)"` and the alignment field
        DateFormat.TIMEZONE_FIELD, the begin index and end index of
        `fieldPosition` will be set to 5 and 8, respectively, for the
        first occurrence of the timezone pattern character `'z'`.

        Returns
        - the formatted date-time string.

        Raises
        - NullPointerException: if any of the parameters is `null`.
        """
        ...


    def formatToCharacterIterator(self, obj: "Object") -> "AttributedCharacterIterator":
        """
        Formats an Object producing an `AttributedCharacterIterator`.
        You can use the returned `AttributedCharacterIterator`
        to build the resulting String, as well as to determine information
        about the resulting String.
        
        Each attribute key of the AttributedCharacterIterator will be of type
        `DateFormat.Field`, with the corresponding attribute value
        being the same as the attribute key.

        Arguments
        - obj: The object to format

        Returns
        - AttributedCharacterIterator describing the formatted value.

        Raises
        - NullPointerException: if obj is null.
        - IllegalArgumentException: if the Format cannot format the
                   given object, or if the Format's pattern string is invalid.

        Since
        - 1.4
        """
        ...


    def parse(self, text: str, pos: "ParsePosition") -> "Date":
        """
        Parses text from a string to produce a `Date`.
        
        The method attempts to parse text starting at the index given by
        `pos`.
        If parsing succeeds, then the index of `pos` is updated
        to the index after the last character used (parsing does not necessarily
        use all characters up to the end of the string), and the parsed
        date is returned. The updated `pos` can be used to
        indicate the starting point for the next call to this method.
        If an error occurs, then the index of `pos` is not
        changed, the error index of `pos` is set to the index of
        the character where the error occurred, and null is returned.
        
        This parsing operation uses the DateFormat.calendar
        calendar to produce a `Date`. All of the `calendar`'s date-time fields are Calendar.clear()
        cleared before parsing, and the `calendar`'s default
        values of the date-time fields are used for any missing
        date-time information. For example, the year value of the
        parsed `Date` is 1970 with GregorianCalendar if
        no year value is given from the parsing operation.  The `TimeZone` value may be overwritten, depending on the given
        pattern and the time zone value in `text`. Any `TimeZone` value that has previously been set by a call to
        .setTimeZone(java.util.TimeZone) setTimeZone may need
        to be restored for further operations.

        Arguments
        - text: A `String`, part of which should be parsed.
        - pos: A `ParsePosition` object with index and error
                     index information as described above.

        Returns
        - A `Date` parsed from the string. In case of
                error, returns null.

        Raises
        - NullPointerException: if `text` or `pos` is null.
        """
        ...


    def toPattern(self) -> str:
        """
        Returns a pattern string describing this date format.

        Returns
        - a pattern string describing this date format.
        """
        ...


    def toLocalizedPattern(self) -> str:
        """
        Returns a localized pattern string describing this date format.

        Returns
        - a localized pattern string describing this date format.
        """
        ...


    def applyPattern(self, pattern: str) -> None:
        """
        Applies the given pattern string to this date format.

        Arguments
        - pattern: the new date and time pattern for this date format

        Raises
        - NullPointerException: if the given pattern is null
        - IllegalArgumentException: if the given pattern is invalid
        """
        ...


    def applyLocalizedPattern(self, pattern: str) -> None:
        """
        Applies the given localized pattern string to this date format.

        Arguments
        - pattern: a String to be mapped to the new date and time format
               pattern for this format

        Raises
        - NullPointerException: if the given pattern is null
        - IllegalArgumentException: if the given pattern is invalid
        """
        ...


    def getDateFormatSymbols(self) -> "DateFormatSymbols":
        """
        Gets a copy of the date and time format symbols of this date format.

        Returns
        - the date and time format symbols of this date format

        See
        - .setDateFormatSymbols
        """
        ...


    def setDateFormatSymbols(self, newFormatSymbols: "DateFormatSymbols") -> None:
        """
        Sets the date and time format symbols of this date format.

        Arguments
        - newFormatSymbols: the new date and time format symbols

        Raises
        - NullPointerException: if the given newFormatSymbols is null

        See
        - .getDateFormatSymbols
        """
        ...


    def clone(self) -> "Object":
        """
        Creates a copy of this `SimpleDateFormat`. This also
        clones the format's date format symbols.

        Returns
        - a clone of this `SimpleDateFormat`
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code value for this `SimpleDateFormat` object.

        Returns
        - the hash code value for this `SimpleDateFormat` object.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares the given object with this `SimpleDateFormat` for
        equality.

        Returns
        - True if the given object is equal to this
        `SimpleDateFormat`
        """
        ...



"""
Python module generated from Java source file java.io.StringReader

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class StringReader(Reader):

    def __init__(self, s: str):
        """
        Creates a new string reader.

        Arguments
        - s: String providing the character stream.
        """
        ...


    def read(self) -> int:
        """
        Reads a single character.

        Returns
        - The character read, or -1 if the end of the stream has been
                    reached

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def read(self, cbuf: list[str], off: int, len: int) -> int:
        """
        Reads characters into a portion of an array.
        
         If `len` is zero, then no characters are read and `0` is
        returned; otherwise, there is an attempt to read at least one character.
        If no character is available because the stream is at its end, the value
        `-1` is returned; otherwise, at least one character is read and
        stored into `cbuf`.

        Arguments
        - cbuf: 
        - off: 
        - len: 

        Returns
        - 

        Raises
        - IndexOutOfBoundsException: 
        - IOException: 
        """
        ...


    def skip(self, n: int) -> int:
        """
        Skips characters. If the stream is already at its end before this method
        is invoked, then no characters are skipped and zero is returned.
        
        The `n` parameter may be negative, even though the
        `skip` method of the Reader superclass throws
        an exception in this case. Negative values of `n` cause the
        stream to skip backwards. Negative return values indicate a skip
        backwards. It is not possible to skip backwards past the beginning of
        the string.
        
        If the entire string has been read or skipped, then this method has
        no effect and always returns `0`.

        Arguments
        - n: 

        Returns
        - 

        Raises
        - IOException: 
        """
        ...


    def ready(self) -> bool:
        """
        Tells whether this stream is ready to be read.

        Returns
        - True if the next read() is guaranteed not to block for input

        Raises
        - IOException: If the stream is closed
        """
        ...


    def markSupported(self) -> bool:
        """
        Tells whether this stream supports the mark() operation, which it does.
        """
        ...


    def mark(self, readAheadLimit: int) -> None:
        """
        Marks the present position in the stream.  Subsequent calls to reset()
        will reposition the stream to this point.

        Arguments
        - readAheadLimit: Limit on the number of characters that may be
                                read while still preserving the mark.  Because
                                the stream's input comes from a string, there
                                is no actual limit, so this argument must not
                                be negative, but is otherwise ignored.

        Raises
        - IllegalArgumentException: If `readAheadLimit < 0`
        - IOException: If an I/O error occurs
        """
        ...


    def reset(self) -> None:
        """
        Resets the stream to the most recent mark, or to the beginning of the
        string if it has never been marked.

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def close(self) -> None:
        """
        Closes the stream and releases any system resources associated with
        it. Once the stream has been closed, further read(),
        ready(), mark(), or reset() invocations will throw an IOException.
        Closing a previously closed stream has no effect. This method will block
        while there is another thread blocking on the reader.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Vex

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Vex(Monster):
    """
    Represents a Vex.
    """

    def isCharging(self) -> bool:
        """
        Gets the charging state of this entity.
        
        When this entity is charging it will having a glowing red texture.

        Returns
        - charging state
        """
        ...


    def setCharging(self, charging: bool) -> None:
        """
        Sets the charging state of this entity.
        
        When this entity is charging it will having a glowing red texture.

        Arguments
        - charging: new state
        """
        ...


    def getBound(self) -> "Location":
        """
        Gets the bound of this entity.
        
        An idle vex will navigate a 15x11x15 area centered around its bound
        location.
        
        When summoned by an Evoker, this location will be set to that of the
        summoner.

        Returns
        - Location of the bound or null if not set
        """
        ...


    def setBound(self, location: "Location") -> None:
        """
        Sets the bound of this entity.
        
        An idle vex will navigate a 15x11x15 area centered around its bound
        location.
        
        When summoned by an Evoker, this location will be set to that of the
        summoner.

        Arguments
        - location: Location of the bound or null to clear
        """
        ...


    def getLifeTicks(self) -> int:
        """
        Gets the remaining lifespan of this entity.

        Returns
        - life in ticks
        """
        ...


    def setLifeTicks(self, lifeTicks: int) -> None:
        """
        Sets the remaining lifespan of this entity.

        Arguments
        - lifeTicks: life in ticks, or negative for unlimited lifepan
        """
        ...


    def hasLimitedLife(self) -> bool:
        """
        Gets if the entity has a limited life.

        Returns
        - True if the entity has limited life
        """
        ...



"""
Python module generated from Java source file org.bukkit.generator.structure.GeneratedStructure

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.generator.structure import *
from org.bukkit.persistence import PersistentDataHolder
from org.bukkit.util import BoundingBox
from typing import Any, Callable, Iterable, Tuple


class GeneratedStructure(PersistentDataHolder):
    """
    Represents a structure placed in the world.

    See
    - StructurePiece
    """

    def getBoundingBox(self) -> "BoundingBox":
        """
        Gets the bounding box of this placed structure.

        Returns
        - bounding box of this placed structure
        """
        ...


    def getStructure(self) -> "Structure":
        """
        Gets the structure that this PlacedStructure represents.

        Returns
        - the structure that this PlacedStructure represents
        """
        ...


    def getPieces(self) -> Iterable["StructurePiece"]:
        """
        Gets all the StructurePiece that make up this PlacedStructure.

        Returns
        - a collection of all the StructurePieces
        """
        ...



"""
Python module generated from Java source file java.io.FilterOutputStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from typing import Any, Callable, Iterable, Tuple


class FilterOutputStream(OutputStream):
    """
    This class is the superclass of all classes that filter output
    streams. These streams sit on top of an already existing output
    stream (the *underlying* output stream) which it uses as its
    basic sink of data, but possibly transforming the data along the
    way or providing additional functionality.
    
    The class `FilterOutputStream` itself simply overrides
    all methods of `OutputStream` with versions that pass
    all requests to the underlying output stream. Subclasses of
    `FilterOutputStream` may further override some of these
    methods as well as provide additional methods and fields.

    Author(s)
    - Jonathan Payne

    Since
    - 1.0
    """

    def __init__(self, out: "OutputStream"):
        """
        Creates an output stream filter built on top of the specified
        underlying output stream.

        Arguments
        - out: the underlying output stream to be assigned to
                       the field `this.out` for later use, or
                       `null` if this instance is to be
                       created without an underlying stream.
        """
        ...


    def write(self, b: int) -> None:
        """
        Writes the specified `byte` to this output stream.
        
        The `write` method of `FilterOutputStream`
        calls the `write` method of its underlying output stream,
        that is, it performs `out.write(b)`.
        
        Implements the abstract `write` method of `OutputStream`.

        Arguments
        - b: the `byte`.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def write(self, b: list[int]) -> None:
        """
        Writes `b.length` bytes to this output stream.
        
        The `write` method of `FilterOutputStream`
        calls its `write` method of three arguments with the
        arguments `b`, `0`, and
        `b.length`.
        
        Note that this method does not call the one-argument
        `write` method of its underlying output stream with
        the single argument `b`.

        Arguments
        - b: the data to be written.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.io.FilterOutputStream.write(byte[], int, int)
        """
        ...


    def write(self, b: list[int], off: int, len: int) -> None:
        """
        Writes `len` bytes from the specified
        `byte` array starting at offset `off` to
        this output stream.
        
        The `write` method of `FilterOutputStream`
        calls the `write` method of one argument on each
        `byte` to output.
        
        Note that this method does not call the `write` method
        of its underlying output stream with the same arguments. Subclasses
        of `FilterOutputStream` should provide a more efficient
        implementation of this method.

        Arguments
        - b: the data.
        - off: the start offset in the data.
        - len: the number of bytes to write.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.io.FilterOutputStream.write(int)
        """
        ...


    def flush(self) -> None:
        """
        Flushes this output stream and forces any buffered output bytes
        to be written out to the stream.
        
        The `flush` method of `FilterOutputStream`
        calls the `flush` method of its underlying output stream.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.io.FilterOutputStream.out
        """
        ...


    def close(self) -> None:
        """
        Closes this output stream and releases any system resources
        associated with the stream.
        
        When not already closed, the `close` method of `FilterOutputStream` calls its `flush` method, and then
        calls the `close` method of its underlying output stream.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.io.FilterOutputStream.out
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.block.BlockIgniteEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block import Block
from org.bukkit.entity import Entity
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockIgniteEvent(BlockEvent, Cancellable):
    """
    Called when a block is ignited. If you want to catch when a Player places
    fire, you need to use BlockPlaceEvent.
    
    If a Block Ignite event is cancelled, the block will not be ignited.
    """

    def __init__(self, theBlock: "Block", cause: "IgniteCause", ignitingEntity: "Entity"):
        ...


    def __init__(self, theBlock: "Block", cause: "IgniteCause", ignitingBlock: "Block"):
        ...


    def __init__(self, theBlock: "Block", cause: "IgniteCause", ignitingEntity: "Entity", ignitingBlock: "Block"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getCause(self) -> "IgniteCause":
        """
        Gets the cause of block ignite.

        Returns
        - An IgniteCause value detailing the cause of block ignition
        """
        ...


    def getPlayer(self) -> "Player":
        """
        Gets the player who ignited this block

        Returns
        - The Player that placed/ignited the fire block, or null if not ignited by a Player.
        """
        ...


    def getIgnitingEntity(self) -> "Entity":
        """
        Gets the entity who ignited this block

        Returns
        - The Entity that placed/ignited the fire block, or null if not ignited by a Entity.
        """
        ...


    def getIgnitingBlock(self) -> "Block":
        """
        Gets the block which ignited this block

        Returns
        - The Block that placed/ignited the fire block, or null if not ignited by a Block.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class IgniteCause(Enum):
        """
        An enum to specify the cause of the ignite
        """

        LAVA = 0
        """
        Block ignition caused by lava.
        """
        FLINT_AND_STEEL = 1
        """
        Block ignition caused by a player or dispenser using flint-and-steel.
        """
        SPREAD = 2
        """
        Block ignition caused by dynamic spreading of fire.
        """
        LIGHTNING = 3
        """
        Block ignition caused by lightning.
        """
        FIREBALL = 4
        """
        Block ignition caused by an entity using a fireball.
        """
        ENDER_CRYSTAL = 5
        """
        Block ignition caused by an Ender Crystal.
        """
        EXPLOSION = 6
        """
        Block ignition caused by explosion.
        """
        ARROW = 7
        """
        Block ignition caused by a flaming arrow.
        """



"""
Python module generated from Java source file org.bukkit.entity.Damageable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.attribute import Attribute
from org.bukkit.damage import DamageSource
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Damageable(Entity):
    """
    Represents an Entity that has health and can take damage.
    """

    def damage(self, amount: float) -> None:
        """
        Deals the given amount of damage to this entity.

        Arguments
        - amount: Amount of damage to deal
        """
        ...


    def damage(self, amount: float, source: "Entity") -> None:
        """
        Deals the given amount of damage to this entity from a specified
        Entity.

        Arguments
        - amount: amount of damage to deal
        - source: entity to which the damage should be attributed
        """
        ...


    def damage(self, amount: float, damageSource: "DamageSource") -> None:
        """
        Deals the given amount of damage to this entity from a specified
        DamageSource.

        Arguments
        - amount: amount of damage to deal
        - damageSource: source to which the damage should be attributed
        """
        ...


    def getHealth(self) -> float:
        """
        Gets the entity's health from 0 to .getMaxHealth(), where 0 is dead.

        Returns
        - Health represented from 0 to max
        """
        ...


    def setHealth(self, health: float) -> None:
        """
        Sets the entity's health from 0 to .getMaxHealth(), where 0 is
        dead.

        Arguments
        - health: New health represented from 0 to max

        Raises
        - IllegalArgumentException: Thrown if the health is < 0 or >
            .getMaxHealth()
        """
        ...


    def getAbsorptionAmount(self) -> float:
        """
        Gets the entity's absorption amount.

        Returns
        - absorption amount from 0
        """
        ...


    def setAbsorptionAmount(self, amount: float) -> None:
        """
        Sets the entity's absorption amount.
        
        Note: The amount is capped to the value of
        Attribute.MAX_ABSORPTION. The effect of this method on
        that attribute is currently unspecified and subject to change.

        Arguments
        - amount: new absorption amount from 0

        Raises
        - IllegalArgumentException: thrown if health is < 0 or
        non-finite.
        """
        ...


    def getMaxHealth(self) -> float:
        """
        Gets the maximum health this entity has.

        Returns
        - Maximum health

        Deprecated
        - use Attribute.MAX_HEALTH.
        """
        ...


    def setMaxHealth(self, health: float) -> None:
        """
        Sets the maximum health this entity can have.
        
        If the health of the entity is above the value provided it will be set
        to that value.
        
        Note: An entity with a health bar (Player, EnderDragon,
        Wither, etc...} will have their bar scaled accordingly.

        Arguments
        - health: amount of health to set the maximum to

        Deprecated
        - use Attribute.MAX_HEALTH.
        """
        ...


    def resetMaxHealth(self) -> None:
        """
        Resets the max health to the original amount.

        Deprecated
        - use Attribute.MAX_HEALTH.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.error.Mark

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import Serializable
from org.yaml.snakeyaml.error import *
from org.yaml.snakeyaml.scanner import Constant
from typing import Any, Callable, Iterable, Tuple


class Mark(Serializable):
    """
    It's just a record and its only use is producing nice error messages. Parser does not use it for
    any other purposes.
    """

    def __init__(self, name: str, index: int, line: int, column: int, str: list[str], pointer: int):
        ...


    def __init__(self, name: str, index: int, line: int, column: int, buffer: list[int], pointer: int):
        ...


    def get_snippet(self, indent: int, max_length: int) -> str:
        ...


    def get_snippet(self) -> str:
        ...


    def toString(self) -> str:
        ...


    def getName(self) -> str:
        ...


    def getLine(self) -> int:
        """
        starts with 0

        Returns
        - line number
        """
        ...


    def getColumn(self) -> int:
        """
        starts with 0

        Returns
        - column number
        """
        ...


    def getIndex(self) -> int:
        """
        starts with 0

        Returns
        - character number
        """
        ...


    def getBuffer(self) -> list[int]:
        ...


    def getPointer(self) -> int:
        ...



"""
Python module generated from Java source file java.util.zip.Adler32

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.ref import Reference
from java.util.zip import *
from jdk.internal.vm.annotation import IntrinsicCandidate
from sun.nio.ch import DirectBuffer
from typing import Any, Callable, Iterable, Tuple


class Adler32(Checksum):
    """
    A class that can be used to compute the Adler-32 checksum of a data
    stream. An Adler-32 checksum is almost as reliable as a CRC-32 but
    can be computed much faster.
    
     Passing a `null` argument to a method in this class will cause
    a NullPointerException to be thrown.

    Author(s)
    - David Connelly

    Since
    - 1.1
    """

    def __init__(self):
        """
        Creates a new Adler32 object.
        """
        ...


    def update(self, b: int) -> None:
        """
        Updates the checksum with the specified byte (the low eight
        bits of the argument b).
        """
        ...


    def update(self, b: list[int], off: int, len: int) -> None:
        """
        Updates the checksum with the specified array of bytes.

        Raises
        - ArrayIndexOutOfBoundsException: if `off` is negative, or `len` is negative, or
                `off+len` is negative or greater than the length of
                the array `b`.
        """
        ...


    def update(self, buffer: "ByteBuffer") -> None:
        """
        Updates the checksum with the bytes from the specified buffer.
        
        The checksum is updated with the remaining bytes in the buffer, starting
        at the buffer's position. Upon return, the buffer's position will be
        updated to its limit; its limit will not have been changed.

        Since
        - 1.8
        """
        ...


    def reset(self) -> None:
        """
        Resets the checksum to initial value.
        """
        ...


    def getValue(self) -> int:
        """
        Returns the checksum value.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.TreeMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.io import IOException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.util import Comparator
from java.util import NavigableMap
from java.util import NavigableSet
from java.util import SortedSet
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class TreeMultimap(AbstractSortedKeySortedSetMultimap):
    """
    Implementation of `Multimap` whose keys and values are ordered by their natural ordering or
    by supplied comparators. In all cases, this implementation uses Comparable.compareTo or
    Comparator.compare instead of Object.equals to determine equivalence of
    instances.
    
    **Warning:** The comparators or comparables used must be *consistent with equals* as
    explained by the Comparable class specification. Otherwise, the resulting multiset will
    violate the general contract of SetMultimap, which is specified in terms of Object.equals.
    
    The collections returned by `keySet` and `asMap` iterate through the keys
    according to the key comparator ordering or the natural ordering of the keys. Similarly, `get`, `removeAll`, and `replaceValues` return collections that iterate through the
    values according to the value comparator ordering or the natural ordering of the values. The
    collections generated by `entries`, `keys`, and `values` iterate across the
    keys according to the above key ordering, and for each key they iterate across the values
    according to the value ordering.
    
    The multimap does not store duplicate key-value pairs. Adding a new key-value pair equal to an
    existing key-value pair has no effect.
    
    Null keys and values are permitted (provided, of course, that the respective comparators
    support them). All optional multimap methods are supported, and all returned views are
    modifiable.
    
    This class is not threadsafe when any concurrent operations update the multimap. Concurrent
    read operations will work correctly. To allow concurrent update operations, wrap your multimap
    with a call to Multimaps.synchronizedSortedSetMultimap.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#multimap">`Multimap`</a>.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0
    """

    @staticmethod
    def create() -> "TreeMultimap"["K", "V"]:
        """
        Creates an empty `TreeMultimap` ordered by the natural ordering of its keys and values.
        """
        ...


    @staticmethod
    def create(keyComparator: "Comparator"["K"], valueComparator: "Comparator"["V"]) -> "TreeMultimap"["K", "V"]:
        """
        Creates an empty `TreeMultimap` instance using explicit comparators. Neither comparator
        may be null; use Ordering.natural() to specify natural order.

        Arguments
        - keyComparator: the comparator that determines the key ordering
        - valueComparator: the comparator that determines the value ordering
        """
        ...


    @staticmethod
    def create(multimap: "Multimap"["K", "V"]) -> "TreeMultimap"["K", "V"]:
        """
        Constructs a `TreeMultimap`, ordered by the natural ordering of its keys and values, with
        the same mappings as the specified multimap.

        Arguments
        - multimap: the multimap whose contents are copied to this multimap
        """
        ...


    def keyComparator(self) -> "Comparator"["K"]:
        """
        Returns the comparator that orders the multimap keys.

        Deprecated
        - Use `((NavigableSet<K>) multimap.keySet()).comparator()` instead.
        """
        ...


    def valueComparator(self) -> "Comparator"["V"]:
        ...


    def get(self, key: "K") -> "NavigableSet"["V"]:
        """
        Since
        - 14.0 (present with return type `SortedSet` since 2.0)
        """
        ...


    def keySet(self) -> "NavigableSet"["K"]:
        """
        
        
        Because a `TreeMultimap` has unique sorted keys, this method returns a NavigableSet, instead of the java.util.Set specified in the Multimap
        interface.

        Since
        - 14.0 (present with return type `SortedSet` since 2.0)
        """
        ...


    def asMap(self) -> "NavigableMap"["K", Iterable["V"]]:
        """
        
        
        Because a `TreeMultimap` has unique sorted keys, this method returns a NavigableMap, instead of the java.util.Map specified in the Multimap
        interface.

        Since
        - 14.0 (present with return type `SortedMap` since 2.0)
        """
        ...



"""
Python module generated from Java source file org.bukkit.scoreboard.Objective

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import OfflinePlayer
from org.bukkit.scoreboard import *
from typing import Any, Callable, Iterable, Tuple


class Objective:
    """
    An objective on a scoreboard that can show scores specific to entries. This
    objective is only relevant to the display of the associated .getScoreboard() scoreboard.
    """

    def getName(self) -> str:
        """
        Gets the name of this Objective

        Returns
        - this objective's name

        Raises
        - IllegalStateException: if this objective has been unregistered
        """
        ...


    def getDisplayName(self) -> str:
        """
        Gets the name displayed to players for this objective

        Returns
        - this objective's display name

        Raises
        - IllegalStateException: if this objective has been unregistered
        """
        ...


    def setDisplayName(self, displayName: str) -> None:
        """
        Sets the name displayed to players for this objective.

        Arguments
        - displayName: Display name to set

        Raises
        - IllegalStateException: if this objective has been unregistered
        """
        ...


    def getCriteria(self) -> str:
        """
        Gets the criteria this objective tracks.

        Returns
        - this objective's criteria

        Raises
        - IllegalStateException: if this objective has been unregistered

        Deprecated
        - use .getTrackedCriteria()
        """
        ...


    def getTrackedCriteria(self) -> "Criteria":
        """
        Gets the criteria this objective tracks.

        Returns
        - this objective's criteria

        Raises
        - IllegalStateException: if this objective has been unregistered
        """
        ...


    def isModifiable(self) -> bool:
        """
        Gets if the objective's scores can be modified directly by a plugin.

        Returns
        - True if scores are modifiable

        Raises
        - IllegalStateException: if this objective has been unregistered

        See
        - Criterias.HEALTH
        """
        ...


    def getScoreboard(self) -> "Scoreboard":
        """
        Gets the scoreboard to which this objective is attached.

        Returns
        - Owning scoreboard, or null if it has been .unregister()
            unregistered
        """
        ...


    def unregister(self) -> None:
        """
        Unregisters this objective from the Scoreboard scoreboard.

        Raises
        - IllegalStateException: if this objective has been unregistered
        """
        ...


    def setDisplaySlot(self, slot: "DisplaySlot") -> None:
        """
        Sets this objective to display on the specified slot for the
        scoreboard, removing it from any other display slot.

        Arguments
        - slot: display slot to change, or null to not display

        Raises
        - IllegalStateException: if this objective has been unregistered
        """
        ...


    def getDisplaySlot(self) -> "DisplaySlot":
        """
        Gets the display slot this objective is displayed at.

        Returns
        - the display slot for this objective, or null if not displayed

        Raises
        - IllegalStateException: if this objective has been unregistered
        """
        ...


    def setRenderType(self, renderType: "RenderType") -> None:
        """
        Sets manner in which this objective will be rendered.

        Arguments
        - renderType: new render type

        Raises
        - IllegalStateException: if this objective has been unregistered
        """
        ...


    def getRenderType(self) -> "RenderType":
        """
        Sets manner in which this objective will be rendered.

        Returns
        - the render type

        Raises
        - IllegalStateException: if this objective has been unregistered
        """
        ...


    def getScore(self, player: "OfflinePlayer") -> "Score":
        """
        Gets a player's Score for an Objective on this Scoreboard

        Arguments
        - player: Player for the Score

        Returns
        - Score tracking the Objective and player specified

        Raises
        - IllegalStateException: if this objective has been unregistered

        See
        - .getScore(String)

        Deprecated
        - Scoreboards can contain entries that aren't players
        """
        ...


    def getScore(self, entry: str) -> "Score":
        """
        Gets an entry's Score for an Objective on this Scoreboard.

        Arguments
        - entry: Entry for the Score

        Returns
        - Score tracking the Objective and entry specified

        Raises
        - IllegalStateException: if this objective has been unregistered
        - IllegalArgumentException: if entry is longer than 32767 characters.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.AbstractListMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Collections
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractListMultimap(AbstractMapBasedMultimap, ListMultimap):
    """
    Basic implementation of the ListMultimap interface. It's a wrapper around AbstractMapBasedMultimap that converts the returned collections into `Lists`. The .createCollection method must return a `List`.

    Author(s)
    - Jared Levy

    Since
    - 2.0
    """

    def get(self, key: "K") -> list["V"]:
        """
        
        
        Because the values for a given key may have duplicates and follow the insertion ordering,
        this method returns a List, instead of the Collection specified in the Multimap interface.
        """
        ...


    def removeAll(self, key: "Object") -> list["V"]:
        """
        
        
        Because the values for a given key may have duplicates and follow the insertion ordering,
        this method returns a List, instead of the Collection specified in the Multimap interface.
        """
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> list["V"]:
        """
        
        
        Because the values for a given key may have duplicates and follow the insertion ordering,
        this method returns a List, instead of the Collection specified in the Multimap interface.
        """
        ...


    def put(self, key: "K", value: "V") -> bool:
        """
        Stores a key-value pair in the multimap.

        Arguments
        - key: key to store in the multimap
        - value: value to store in the multimap

        Returns
        - `True` always
        """
        ...


    def asMap(self) -> dict["K", Iterable["V"]]:
        """
        
        
        Though the method signature doesn't say so explicitly, the returned map has List
        values.
        """
        ...


    def equals(self, object: "Object") -> bool:
        """
        Compares the specified object to this multimap for equality.
        
        Two `ListMultimap` instances are equal if, for each key, they contain the same values
        in the same order. If the value orderings disagree, the multimaps will not be considered equal.
        """
        ...



from .Sapling import Sapling
from .BigDripleaf import BigDripleaf
from .WallSign import WallSign
from .Chain import Chain
from .Slab import Slab
from .Vault import Vault
from .Comparator import Comparator
from .Switch import Switch
from .CaveVines import CaveVines
from .CopperBulb import CopperBulb
from .SculkSensor import SculkSensor
from .Fence import Fence
from .Campfire import Campfire
from .Crafter import Crafter
from .MangrovePropagule import MangrovePropagule
from .Lectern import Lectern
from .Repeater import Repeater
from .PistonHead import PistonHead
from .Dripleaf import Dripleaf
from .Sign import Sign
from .RedstoneWire import RedstoneWire
from .TechnicalPiston import TechnicalPiston
from .Observer import Observer
from .Candle import Candle
from .PitcherCrop import PitcherCrop
from .DaylightDetector import DaylightDetector
from .Hopper import Hopper
from .BubbleColumn import BubbleColumn
from .Farmland import Farmland
from .Beehive import Beehive
from .TrialSpawner import TrialSpawner
from .Skull import Skull
from .CreakingHeart import CreakingHeart
from .TurtleEgg import TurtleEgg
from .Fire import Fire
from .Jigsaw import Jigsaw
from .RedstoneWallTorch import RedstoneWallTorch
from .Wall import Wall
from .HangingMoss import HangingMoss
from .Stairs import Stairs
from .RedstoneRail import RedstoneRail
from .GlassPane import GlassPane
from .Lantern import Lantern
from .TripwireHook import TripwireHook
from .Snow import Snow
from .DecoratedPot import DecoratedPot
from .HangingSign import HangingSign
from .Bell import Bell
from .Chest import Chest
from .NoteBlock import NoteBlock
from .SculkVein import SculkVein
from .TNT import TNT
from .ResinClump import ResinClump
from .Dispenser import Dispenser
from .WallHangingSign import WallHangingSign
from .MossyCarpet import MossyCarpet
from .CoralWallFan import CoralWallFan
from .Tripwire import Tripwire
from .Furnace import Furnace
from .EnderChest import EnderChest
from .EndPortalFrame import EndPortalFrame
from .CommandBlock import CommandBlock
from .Barrel import Barrel
from .Grindstone import Grindstone
from .CalibratedSculkSensor import CalibratedSculkSensor
from .SeaPickle import SeaPickle
from .Gate import Gate
from .CaveVinesPlant import CaveVinesPlant
from .Piston import Piston
from .LightningRod import LightningRod
from .Leaves import Leaves
from .Bed import Bed
from .Door import Door
from .PinkPetals import PinkPetals
from .RespawnAnchor import RespawnAnchor
from .SculkShrieker import SculkShrieker
from .Cake import Cake
from .Scaffolding import Scaffolding
from .AmethystCluster import AmethystCluster
from .SmallDripleaf import SmallDripleaf
from .Bamboo import Bamboo
from .Jukebox import Jukebox
from .GlowLichen import GlowLichen
from .StructureBlock import StructureBlock
from .PointedDripstone import PointedDripstone
from .TrapDoor import TrapDoor
from .WallSkull import WallSkull
from .SculkCatalyst import SculkCatalyst
from .Ladder import Ladder
from .Light import Light
from .ChiseledBookshelf import ChiseledBookshelf
from .BrewingStand import BrewingStand
from .Cocoa import Cocoa


"""
Python module generated from Java source file org.bukkit.block.PistonMoveReaction

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class PistonMoveReaction(Enum):
    """
    Represents how a block or entity will react when interacting with a piston
    when it is extending or retracting.
    """

    MOVE = (0)
    """
    Indicates that the block can be pushed or pulled.
    """
    BREAK = (1)
    """
    Indicates the block is fragile and will break if pushed on.
    """
    BLOCK = (2)
    """
    Indicates that the block will resist being pushed or pulled.
    """
    IGNORE = (3)
    """
    Indicates that the entity will ignore any interaction(s) with
    pistons.
    
    Blocks should use PistonMoveReaction.BLOCK.
    """
    PUSH_ONLY = (4)
    """
    Indicates that the block can only be pushed by pistons, not pulled.
    """


    def getId(self) -> int:
        """
        Returns
        - The ID of the move reaction

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def getById(id: int) -> "PistonMoveReaction":
        """
        Arguments
        - id: An ID

        Returns
        - The move reaction with that ID

        Deprecated
        - Magic value
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Candle

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Lightable
from org.bukkit.block.data import Waterlogged
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Candle(Lightable, Waterlogged):
    """
    'candles' represents the number of candles which are present.
    """

    def getCandles(self) -> int:
        """
        Gets the value of the 'candles' property.

        Returns
        - the 'candles' value
        """
        ...


    def setCandles(self, candles: int) -> None:
        """
        Sets the value of the 'candles' property.

        Arguments
        - candles: the new 'candles' value
        """
        ...


    def getMaximumCandles(self) -> int:
        """
        Gets the maximum allowed value of the 'candles' property.

        Returns
        - the maximum 'candles' value
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.JdkBackedImmutableMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.common.primitives import Ints
from com.google.errorprone.annotations.concurrent import LazyInit
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class JdkBackedImmutableMultiset(ImmutableMultiset):
    """
    An implementation of ImmutableMultiset backed by a JDK Map and a list of entries. Used to protect
    against hash flooding attacks.

    Author(s)
    - Louis Wasserman
    """

    def count(self, element: "Object") -> int:
        ...


    def elementSet(self) -> "ImmutableSet"["E"]:
        ...


    def size(self) -> int:
        ...



"""
Python module generated from Java source file java.math.BigInteger

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.io import ObjectStreamException
from java.io import ObjectStreamField
from java.math import *
from java.util import Arrays
from java.util import Objects
from java.util import Random
from java.util.concurrent import ThreadLocalRandom
from jdk.internal.math import DoubleConsts
from jdk.internal.math import FloatConsts
from jdk.internal.vm.annotation import ForceInline
from jdk.internal.vm.annotation import IntrinsicCandidate
from jdk.internal.vm.annotation import Stable
from typing import Any, Callable, Iterable, Tuple


class BigInteger(Number, Comparable):

    ZERO = BigInteger(int[0], 0)
    """
    The BigInteger constant zero.

    Since
    - 1.2
    """
    ONE = valueOf(1)
    """
    The BigInteger constant one.

    Since
    - 1.2
    """
    TWO = valueOf(2)
    """
    The BigInteger constant two.

    Since
    - 9
    """
    TEN = valueOf(10)
    """
    The BigInteger constant ten.

    Since
    - 1.5
    """


    def __init__(self, val: list[int], off: int, len: int):
        """
        Translates a byte sub-array containing the two's-complement binary
        representation of a BigInteger into a BigInteger.  The sub-array is
        specified via an offset into the array and a length.  The sub-array is
        assumed to be in *big-endian* byte-order: the most significant
        byte is the element at index `off`.  The `val` array is
        assumed to be unchanged for the duration of the constructor call.
        
        An `IndexOutOfBoundsException` is thrown if the length of the array
        `val` is non-zero and either `off` is negative, `len`
        is negative, or `off+len` is greater than the length of
        `val`.

        Arguments
        - val: byte array containing a sub-array which is the big-endian
                two's-complement binary representation of a BigInteger.
        - off: the start offset of the binary representation.
        - len: the number of bytes to use.

        Raises
        - NumberFormatException: `val` is zero bytes long.
        - IndexOutOfBoundsException: if the provided array offset and
                length would cause an index into the byte array to be
                negative or greater than or equal to the array length.

        Since
        - 9
        """
        ...


    def __init__(self, val: list[int]):
        """
        Translates a byte array containing the two's-complement binary
        representation of a BigInteger into a BigInteger.  The input array is
        assumed to be in *big-endian* byte-order: the most significant
        byte is in the zeroth element.  The `val` array is assumed to be
        unchanged for the duration of the constructor call.

        Arguments
        - val: big-endian two's-complement binary representation of a
                BigInteger.

        Raises
        - NumberFormatException: `val` is zero bytes long.
        """
        ...


    def __init__(self, signum: int, magnitude: list[int], off: int, len: int):
        """
        Translates the sign-magnitude representation of a BigInteger into a
        BigInteger.  The sign is represented as an integer signum value: -1 for
        negative, 0 for zero, or 1 for positive.  The magnitude is a sub-array of
        a byte array in *big-endian* byte-order: the most significant byte
        is the element at index `off`.  A zero value of the length
        `len` is permissible, and will result in a BigInteger value of 0,
        whether signum is -1, 0 or 1.  The `magnitude` array is assumed to
        be unchanged for the duration of the constructor call.
        
        An `IndexOutOfBoundsException` is thrown if the length of the array
        `magnitude` is non-zero and either `off` is negative,
        `len` is negative, or `off+len` is greater than the length of
        `magnitude`.

        Arguments
        - signum: signum of the number (-1 for negative, 0 for zero, 1
                for positive).
        - magnitude: big-endian binary representation of the magnitude of
                the number.
        - off: the start offset of the binary representation.
        - len: the number of bytes to use.

        Raises
        - NumberFormatException: `signum` is not one of the three
                legal values (-1, 0, and 1), or `signum` is 0 and
                `magnitude` contains one or more non-zero bytes.
        - IndexOutOfBoundsException: if the provided array offset and
                length would cause an index into the byte array to be
                negative or greater than or equal to the array length.

        Since
        - 9
        """
        ...


    def __init__(self, signum: int, magnitude: list[int]):
        """
        Translates the sign-magnitude representation of a BigInteger into a
        BigInteger.  The sign is represented as an integer signum value: -1 for
        negative, 0 for zero, or 1 for positive.  The magnitude is a byte array
        in *big-endian* byte-order: the most significant byte is the
        zeroth element.  A zero-length magnitude array is permissible, and will
        result in a BigInteger value of 0, whether signum is -1, 0 or 1.  The
        `magnitude` array is assumed to be unchanged for the duration of
        the constructor call.

        Arguments
        - signum: signum of the number (-1 for negative, 0 for zero, 1
                for positive).
        - magnitude: big-endian binary representation of the magnitude of
                the number.

        Raises
        - NumberFormatException: `signum` is not one of the three
                legal values (-1, 0, and 1), or `signum` is 0 and
                `magnitude` contains one or more non-zero bytes.
        """
        ...


    def __init__(self, val: str, radix: int):
        """
        Translates the String representation of a BigInteger in the
        specified radix into a BigInteger.  The String representation
        consists of an optional minus or plus sign followed by a
        sequence of one or more digits in the specified radix.  The
        character-to-digit mapping is provided by Character.digit(char, int) Character.digit.  The String may
        not contain any extraneous characters (whitespace, for
        example).

        Arguments
        - val: String representation of BigInteger.
        - radix: radix to be used in interpreting `val`.

        Raises
        - NumberFormatException: `val` is not a valid representation
                of a BigInteger in the specified radix, or `radix` is
                outside the range from Character.MIN_RADIX to
                Character.MAX_RADIX, inclusive.
        """
        ...


    def __init__(self, val: str):
        """
        Translates the decimal String representation of a BigInteger
        into a BigInteger.  The String representation consists of an
        optional minus or plus sign followed by a sequence of one or
        more decimal digits.  The character-to-digit mapping is
        provided by Character.digit(char, int)
        Character.digit.  The String may not contain any extraneous
        characters (whitespace, for example).

        Arguments
        - val: decimal String representation of BigInteger.

        Raises
        - NumberFormatException: `val` is not a valid representation
                of a BigInteger.
        """
        ...


    def __init__(self, numBits: int, rnd: "Random"):
        """
        Constructs a randomly generated BigInteger, uniformly distributed over
        the range 0 to (2<sup>`numBits`</sup> - 1), inclusive.
        The uniformity of the distribution assumes that a fair source of random
        bits is provided in `rnd`.  Note that this constructor always
        constructs a non-negative BigInteger.

        Arguments
        - numBits: maximum bitLength of the new BigInteger.
        - rnd: source of randomness to be used in computing the new
                BigInteger.

        Raises
        - IllegalArgumentException: `numBits` is negative.

        See
        - .bitLength()
        """
        ...


    def __init__(self, bitLength: int, certainty: int, rnd: "Random"):
        """
        Constructs a randomly generated positive BigInteger that is probably
        prime, with the specified bitLength.

        Arguments
        - bitLength: bitLength of the returned BigInteger.
        - certainty: a measure of the uncertainty that the caller is
                willing to tolerate.  The probability that the new BigInteger
                represents a prime number will exceed
                (1 - 1/2<sup>`certainty`</sup>).  The execution time of
                this constructor is proportional to the value of this parameter.
        - rnd: source of random bits used to select candidates to be
                tested for primality.

        Raises
        - ArithmeticException: `bitLength < 2` or `bitLength` is too large.

        See
        - .bitLength()

        Unknown Tags
        - It is recommended that the .probablePrime probablePrime
        method be used in preference to this constructor unless there
        is a compelling need to specify a certainty.
        """
        ...


    @staticmethod
    def probablePrime(bitLength: int, rnd: "Random") -> "BigInteger":
        """
        Returns a positive BigInteger that is probably prime, with the
        specified bitLength. The probability that a BigInteger returned
        by this method is composite does not exceed 2<sup>-100</sup>.

        Arguments
        - bitLength: bitLength of the returned BigInteger.
        - rnd: source of random bits used to select candidates to be
                tested for primality.

        Returns
        - a BigInteger of `bitLength` bits that is probably prime

        Raises
        - ArithmeticException: `bitLength < 2` or `bitLength` is too large.

        See
        - .bitLength()

        Since
        - 1.4
        """
        ...


    def nextProbablePrime(self) -> "BigInteger":
        """
        Returns the first integer greater than this `BigInteger` that
        is probably prime.  The probability that the number returned by this
        method is composite does not exceed 2<sup>-100</sup>. This method will
        never skip over a prime when searching: if it returns `p`, there
        is no prime `q` such that `this < q < p`.

        Returns
        - the first integer greater than this `BigInteger` that
                is probably prime.

        Raises
        - ArithmeticException: `this < 0` or `this` is too large.

        Since
        - 1.5
        """
        ...


    @staticmethod
    def valueOf(val: int) -> "BigInteger":
        """
        Returns a BigInteger whose value is equal to that of the
        specified `long`.

        Arguments
        - val: value of the BigInteger to return.

        Returns
        - a BigInteger with the specified value.

        Unknown Tags
        - This static factory method is provided in preference
        to a (`long`) constructor because it allows for reuse of
        frequently used BigIntegers.
        """
        ...


    def add(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this + val)`.

        Arguments
        - val: value to be added to this BigInteger.

        Returns
        - `this + val`
        """
        ...


    def subtract(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this - val)`.

        Arguments
        - val: value to be subtracted from this BigInteger.

        Returns
        - `this - val`
        """
        ...


    def multiply(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this * val)`.

        Arguments
        - val: value to be multiplied by this BigInteger.

        Returns
        - `this * val`

        Unknown Tags
        - An implementation may offer better algorithmic
        performance when `val == this`.
        """
        ...


    def divide(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this / val)`.

        Arguments
        - val: value by which this BigInteger is to be divided.

        Returns
        - `this / val`

        Raises
        - ArithmeticException: if `val` is zero.
        """
        ...


    def divideAndRemainder(self, val: "BigInteger") -> list["BigInteger"]:
        """
        Returns an array of two BigIntegers containing `(this / val)`
        followed by `(this % val)`.

        Arguments
        - val: value by which this BigInteger is to be divided, and the
                remainder computed.

        Returns
        - an array of two BigIntegers: the quotient `(this / val)`
                is the initial element, and the remainder `(this % val)`
                is the final element.

        Raises
        - ArithmeticException: if `val` is zero.
        """
        ...


    def remainder(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this % val)`.

        Arguments
        - val: value by which this BigInteger is to be divided, and the
                remainder computed.

        Returns
        - `this % val`

        Raises
        - ArithmeticException: if `val` is zero.
        """
        ...


    def pow(self, exponent: int) -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this<sup>exponent</sup>)`.
        Note that `exponent` is an integer rather than a BigInteger.

        Arguments
        - exponent: exponent to which this BigInteger is to be raised.

        Returns
        - `this<sup>exponent</sup>`

        Raises
        - ArithmeticException: `exponent` is negative.  (This would
                cause the operation to yield a non-integer value.)
        """
        ...


    def sqrt(self) -> "BigInteger":
        """
        Returns the integer square root of this BigInteger.  The integer square
        root of the corresponding mathematical integer `n` is the largest
        mathematical integer `s` such that `s*s <= n`.  It is equal
        to the value of `floor(sqrt(n))`, where `sqrt(n)` denotes the
        real square root of `n` treated as a real.  Note that the integer
        square root will be less than the real square root if the latter is not
        representable as an integral value.

        Returns
        - the integer square root of `this`

        Raises
        - ArithmeticException: if `this` is negative.  (The square
                root of a negative integer `val` is
                `(i * sqrt(-val))` where *i* is the
                *imaginary unit* and is equal to
                `sqrt(-1)`.)

        Since
        - 9
        """
        ...


    def sqrtAndRemainder(self) -> list["BigInteger"]:
        """
        Returns an array of two BigIntegers containing the integer square root
        `s` of `this` and its remainder `this - s*s`,
        respectively.

        Returns
        - an array of two BigIntegers with the integer square root at
                offset 0 and the remainder at offset 1

        Raises
        - ArithmeticException: if `this` is negative.  (The square
                root of a negative integer `val` is
                `(i * sqrt(-val))` where *i* is the
                *imaginary unit* and is equal to
                `sqrt(-1)`.)

        See
        - .sqrt()

        Since
        - 9
        """
        ...


    def gcd(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is the greatest common divisor of
        `abs(this)` and `abs(val)`.  Returns 0 if
        `this == 0 && val == 0`.

        Arguments
        - val: value with which the GCD is to be computed.

        Returns
        - `GCD(abs(this), abs(val))`
        """
        ...


    def abs(self) -> "BigInteger":
        """
        Returns a BigInteger whose value is the absolute value of this
        BigInteger.

        Returns
        - `abs(this)`
        """
        ...


    def negate(self) -> "BigInteger":
        """
        Returns a BigInteger whose value is `(-this)`.

        Returns
        - `-this`
        """
        ...


    def signum(self) -> int:
        """
        Returns the signum function of this BigInteger.

        Returns
        - -1, 0 or 1 as the value of this BigInteger is negative, zero or
                positive.
        """
        ...


    def mod(self, m: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this mod m`).  This method
        differs from `remainder` in that it always returns a
        *non-negative* BigInteger.

        Arguments
        - m: the modulus.

        Returns
        - `this mod m`

        Raises
        - ArithmeticException: `m` &le; 0

        See
        - .remainder
        """
        ...


    def modPow(self, exponent: "BigInteger", m: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is
        `(this<sup>exponent</sup> mod m)`.  (Unlike `pow`, this
        method permits negative exponents.)

        Arguments
        - exponent: the exponent.
        - m: the modulus.

        Returns
        - `this<sup>exponent</sup> mod m`

        Raises
        - ArithmeticException: `m` &le; 0 or the exponent is
                negative and this BigInteger is not *relatively
                prime* to `m`.

        See
        - .modInverse
        """
        ...


    def modInverse(self, m: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this`<sup>-1</sup> `mod m)`.

        Arguments
        - m: the modulus.

        Returns
        - `this`<sup>-1</sup> `mod m`.

        Raises
        - ArithmeticException: `m` &le; 0, or this BigInteger
                has no multiplicative inverse mod m (that is, this BigInteger
                is not *relatively prime* to m).
        """
        ...


    def shiftLeft(self, n: int) -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this << n)`.
        The shift distance, `n`, may be negative, in which case
        this method performs a right shift.
        (Computes `floor(this * 2<sup>n</sup>)`.)

        Arguments
        - n: shift distance, in bits.

        Returns
        - `this << n`

        See
        - .shiftRight
        """
        ...


    def shiftRight(self, n: int) -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this >> n)`.  Sign
        extension is performed.  The shift distance, `n`, may be
        negative, in which case this method performs a left shift.
        (Computes `floor(this / 2<sup>n</sup>)`.)

        Arguments
        - n: shift distance, in bits.

        Returns
        - `this >> n`

        See
        - .shiftLeft
        """
        ...


    def and(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this & val)`.  (This
        method returns a negative BigInteger if and only if this and val are
        both negative.)

        Arguments
        - val: value to be AND'ed with this BigInteger.

        Returns
        - `this & val`
        """
        ...


    def or(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this | val)`.  (This method
        returns a negative BigInteger if and only if either this or val is
        negative.)

        Arguments
        - val: value to be OR'ed with this BigInteger.

        Returns
        - `this | val`
        """
        ...


    def xor(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this ^ val)`.  (This method
        returns a negative BigInteger if and only if exactly one of this and
        val are negative.)

        Arguments
        - val: value to be XOR'ed with this BigInteger.

        Returns
        - `this ^ val`
        """
        ...


    def not(self) -> "BigInteger":
        """
        Returns a BigInteger whose value is `(~this)`.  (This method
        returns a negative value if and only if this BigInteger is
        non-negative.)

        Returns
        - `~this`
        """
        ...


    def andNot(self, val: "BigInteger") -> "BigInteger":
        """
        Returns a BigInteger whose value is `(this & ~val)`.  This
        method, which is equivalent to `and(val.not())`, is provided as
        a convenience for masking operations.  (This method returns a negative
        BigInteger if and only if `this` is negative and `val` is
        positive.)

        Arguments
        - val: value to be complemented and AND'ed with this BigInteger.

        Returns
        - `this & ~val`
        """
        ...


    def testBit(self, n: int) -> bool:
        """
        Returns `True` if and only if the designated bit is set.
        (Computes `((this & (1<<n)) != 0)`.)

        Arguments
        - n: index of bit to test.

        Returns
        - `True` if and only if the designated bit is set.

        Raises
        - ArithmeticException: `n` is negative.
        """
        ...


    def setBit(self, n: int) -> "BigInteger":
        """
        Returns a BigInteger whose value is equivalent to this BigInteger
        with the designated bit set.  (Computes `(this | (1<<n))`.)

        Arguments
        - n: index of bit to set.

        Returns
        - `this | (1<<n)`

        Raises
        - ArithmeticException: `n` is negative.
        """
        ...


    def clearBit(self, n: int) -> "BigInteger":
        """
        Returns a BigInteger whose value is equivalent to this BigInteger
        with the designated bit cleared.
        (Computes `(this & ~(1<<n))`.)

        Arguments
        - n: index of bit to clear.

        Returns
        - `this & ~(1<<n)`

        Raises
        - ArithmeticException: `n` is negative.
        """
        ...


    def flipBit(self, n: int) -> "BigInteger":
        """
        Returns a BigInteger whose value is equivalent to this BigInteger
        with the designated bit flipped.
        (Computes `(this ^ (1<<n))`.)

        Arguments
        - n: index of bit to flip.

        Returns
        - `this ^ (1<<n)`

        Raises
        - ArithmeticException: `n` is negative.
        """
        ...


    def getLowestSetBit(self) -> int:
        """
        Returns the index of the rightmost (lowest-order) one bit in this
        BigInteger (the number of zero bits to the right of the rightmost
        one bit).  Returns -1 if this BigInteger contains no one bits.
        (Computes `(this == 0? -1 : log2(this & -this))`.)

        Returns
        - index of the rightmost one bit in this BigInteger.
        """
        ...


    def bitLength(self) -> int:
        """
        Returns the number of bits in the minimal two's-complement
        representation of this BigInteger, *excluding* a sign bit.
        For positive BigIntegers, this is equivalent to the number of bits in
        the ordinary binary representation.  For zero this method returns
        `0`.  (Computes `(ceil(log2(this < 0 ? -this : this+1)))`.)

        Returns
        - number of bits in the minimal two's-complement
                representation of this BigInteger, *excluding* a sign bit.
        """
        ...


    def bitCount(self) -> int:
        """
        Returns the number of bits in the two's complement representation
        of this BigInteger that differ from its sign bit.  This method is
        useful when implementing bit-vector style sets atop BigIntegers.

        Returns
        - number of bits in the two's complement representation
                of this BigInteger that differ from its sign bit.
        """
        ...


    def isProbablePrime(self, certainty: int) -> bool:
        """
        Returns `True` if this BigInteger is probably prime,
        `False` if it's definitely composite.  If
        `certainty` is &le; 0, `True` is
        returned.

        Arguments
        - certainty: a measure of the uncertainty that the caller is
                willing to tolerate: if the call returns `True`
                the probability that this BigInteger is prime exceeds
                (1 - 1/2<sup>`certainty`</sup>).  The execution time of
                this method is proportional to the value of this parameter.

        Returns
        - `True` if this BigInteger is probably prime,
                `False` if it's definitely composite.
        """
        ...


    def compareTo(self, val: "BigInteger") -> int:
        """
        Compares this BigInteger with the specified BigInteger.  This
        method is provided in preference to individual methods for each
        of the six boolean comparison operators (<, ==,
        >, >=, !=, <=).  The suggested
        idiom for performing these comparisons is: `(x.compareTo(y)` &lt;*op*&gt; `0)`, where
        &lt;*op*&gt; is one of the six comparison operators.

        Arguments
        - val: BigInteger to which this BigInteger is to be compared.

        Returns
        - -1, 0 or 1 as this BigInteger is numerically less than, equal
                to, or greater than `val`.
        """
        ...


    def equals(self, x: "Object") -> bool:
        """
        Compares this BigInteger with the specified Object for equality.

        Arguments
        - x: Object to which this BigInteger is to be compared.

        Returns
        - `True` if and only if the specified Object is a
                BigInteger whose value is numerically equal to this BigInteger.
        """
        ...


    def min(self, val: "BigInteger") -> "BigInteger":
        """
        Returns the minimum of this BigInteger and `val`.

        Arguments
        - val: value with which the minimum is to be computed.

        Returns
        - the BigInteger whose value is the lesser of this BigInteger and
                `val`.  If they are equal, either may be returned.
        """
        ...


    def max(self, val: "BigInteger") -> "BigInteger":
        """
        Returns the maximum of this BigInteger and `val`.

        Arguments
        - val: value with which the maximum is to be computed.

        Returns
        - the BigInteger whose value is the greater of this and
                `val`.  If they are equal, either may be returned.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code for this BigInteger.

        Returns
        - hash code for this BigInteger.
        """
        ...


    def toString(self, radix: int) -> str:
        """
        Returns the String representation of this BigInteger in the
        given radix.  If the radix is outside the range from Character.MIN_RADIX to Character.MAX_RADIX inclusive,
        it will default to 10 (as is the case for
        `Integer.toString`).  The digit-to-character mapping
        provided by `Character.forDigit` is used, and a minus
        sign is prepended if appropriate.  (This representation is
        compatible with the .BigInteger(String, int) (String,
        int) constructor.)

        Arguments
        - radix: radix of the String representation.

        Returns
        - String representation of this BigInteger in the given radix.

        See
        - .BigInteger(java.lang.String, int)
        """
        ...


    def toString(self) -> str:
        """
        Returns the decimal String representation of this BigInteger.
        The digit-to-character mapping provided by
        `Character.forDigit` is used, and a minus sign is
        prepended if appropriate.  (This representation is compatible
        with the .BigInteger(String) (String) constructor, and
        allows for String concatenation with Java's + operator.)

        Returns
        - decimal String representation of this BigInteger.

        See
        - .BigInteger(java.lang.String)
        """
        ...


    def toByteArray(self) -> list[int]:
        """
        Returns a byte array containing the two's-complement
        representation of this BigInteger.  The byte array will be in
        *big-endian* byte-order: the most significant byte is in
        the zeroth element.  The array will contain the minimum number
        of bytes required to represent this BigInteger, including at
        least one sign bit, which is `(ceil((this.bitLength() +
        1)/8))`.  (This representation is compatible with the
        .BigInteger(byte[]) (byte[]) constructor.)

        Returns
        - a byte array containing the two's-complement representation of
                this BigInteger.

        See
        - .BigInteger(byte[])
        """
        ...


    def intValue(self) -> int:
        """
        Converts this BigInteger to an `int`.  This
        conversion is analogous to a
        *narrowing primitive conversion* from `long` to
        `int` as defined in
        <cite>The Java Language Specification</cite>:
        if this BigInteger is too big to fit in an
        `int`, only the low-order 32 bits are returned.
        Note that this conversion can lose information about the
        overall magnitude of the BigInteger value as well as return a
        result with the opposite sign.

        Returns
        - this BigInteger converted to an `int`.

        See
        - .intValueExact()

        Unknown Tags
        - 5.1.3 Narrowing Primitive Conversion
        """
        ...


    def longValue(self) -> int:
        """
        Converts this BigInteger to a `long`.  This
        conversion is analogous to a
        *narrowing primitive conversion* from `long` to
        `int` as defined in
        <cite>The Java Language Specification</cite>:
        if this BigInteger is too big to fit in a
        `long`, only the low-order 64 bits are returned.
        Note that this conversion can lose information about the
        overall magnitude of the BigInteger value as well as return a
        result with the opposite sign.

        Returns
        - this BigInteger converted to a `long`.

        See
        - .longValueExact()

        Unknown Tags
        - 5.1.3 Narrowing Primitive Conversion
        """
        ...


    def floatValue(self) -> float:
        """
        Converts this BigInteger to a `float`.  This
        conversion is similar to the
        *narrowing primitive conversion* from `double` to
        `float` as defined in
        <cite>The Java Language Specification</cite>:
        if this BigInteger has too great a magnitude
        to represent as a `float`, it will be converted to
        Float.NEGATIVE_INFINITY or Float.POSITIVE_INFINITY as appropriate.  Note that even when
        the return value is finite, this conversion can lose
        information about the precision of the BigInteger value.

        Returns
        - this BigInteger converted to a `float`.

        Unknown Tags
        - 5.1.3 Narrowing Primitive Conversion
        """
        ...


    def doubleValue(self) -> float:
        """
        Converts this BigInteger to a `double`.  This
        conversion is similar to the
        *narrowing primitive conversion* from `double` to
        `float` as defined in
        <cite>The Java Language Specification</cite>:
        if this BigInteger has too great a magnitude
        to represent as a `double`, it will be converted to
        Double.NEGATIVE_INFINITY or Double.POSITIVE_INFINITY as appropriate.  Note that even when
        the return value is finite, this conversion can lose
        information about the precision of the BigInteger value.

        Returns
        - this BigInteger converted to a `double`.

        Unknown Tags
        - 5.1.3 Narrowing Primitive Conversion
        """
        ...


    def longValueExact(self) -> int:
        """
        Converts this `BigInteger` to a `long`, checking
        for lost information.  If the value of this `BigInteger`
        is out of the range of the `long` type, then an
        `ArithmeticException` is thrown.

        Returns
        - this `BigInteger` converted to a `long`.

        Raises
        - ArithmeticException: if the value of `this` will
        not exactly fit in a `long`.

        See
        - BigInteger.longValue

        Since
        - 1.8
        """
        ...


    def intValueExact(self) -> int:
        """
        Converts this `BigInteger` to an `int`, checking
        for lost information.  If the value of this `BigInteger`
        is out of the range of the `int` type, then an
        `ArithmeticException` is thrown.

        Returns
        - this `BigInteger` converted to an `int`.

        Raises
        - ArithmeticException: if the value of `this` will
        not exactly fit in an `int`.

        See
        - BigInteger.intValue

        Since
        - 1.8
        """
        ...


    def shortValueExact(self) -> int:
        """
        Converts this `BigInteger` to a `short`, checking
        for lost information.  If the value of this `BigInteger`
        is out of the range of the `short` type, then an
        `ArithmeticException` is thrown.

        Returns
        - this `BigInteger` converted to a `short`.

        Raises
        - ArithmeticException: if the value of `this` will
        not exactly fit in a `short`.

        See
        - BigInteger.shortValue

        Since
        - 1.8
        """
        ...


    def byteValueExact(self) -> int:
        """
        Converts this `BigInteger` to a `byte`, checking
        for lost information.  If the value of this `BigInteger`
        is out of the range of the `byte` type, then an
        `ArithmeticException` is thrown.

        Returns
        - this `BigInteger` converted to a `byte`.

        Raises
        - ArithmeticException: if the value of `this` will
        not exactly fit in a `byte`.

        See
        - BigInteger.byteValue

        Since
        - 1.8
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.BoundType

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from enum import Enum
from typing import Any, Callable, Iterable, Tuple


class BoundType(Enum):
    """
    Indicates whether an endpoint of some range is contained in the range itself ("closed") or not
    ("open"). If a range is unbounded on a side, it is neither open nor closed on that side; the
    bound simply does not exist.

    Since
    - 10.0
    """

    OPEN = (False)
    """
    The endpoint value *is not* considered part of the set ("exclusive").
    """
    CLOSED = (True)



"""
Python module generated from Java source file net.md_5.bungee.api.chat.ComponentStyle

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from net.md_5.bungee.api import ChatColor
from net.md_5.bungee.api.chat import *
from typing import Any, Callable, Iterable, Tuple


class ComponentStyle(Cloneable):
    """
    Represents a style that may be applied to a BaseComponent.
    """

    def getColor(self) -> "ChatColor":
        """
        Returns the color of this style. May return null.

        Returns
        - the color of this style, or null if default color
        """
        ...


    def hasColor(self) -> bool:
        """
        Returns whether or not this style has a color set.

        Returns
        - whether a color is set
        """
        ...


    def getFont(self) -> str:
        """
        Returns the font of this style. May return null.

        Returns
        - the font of this style, or null if default font
        """
        ...


    def hasFont(self) -> bool:
        """
        Returns whether or not this style has a font set.

        Returns
        - whether a font is set
        """
        ...


    def isBold(self) -> bool:
        """
        Returns whether this style is bold.

        Returns
        - whether the style is bold
        """
        ...


    def isBoldRaw(self) -> "Boolean":
        """
        Returns whether this style is bold. May return null.

        Returns
        - whether the style is bold, or null if not set
        """
        ...


    def isItalic(self) -> bool:
        """
        Returns whether this style is italic. May return null.

        Returns
        - whether the style is italic
        """
        ...


    def isItalicRaw(self) -> "Boolean":
        """
        Returns whether this style is italic. May return null.

        Returns
        - whether the style is italic, or null if not set
        """
        ...


    def isUnderlined(self) -> bool:
        """
        Returns whether this style is underlined.

        Returns
        - whether the style is underlined
        """
        ...


    def isUnderlinedRaw(self) -> "Boolean":
        """
        Returns whether this style is underlined. May return null.

        Returns
        - whether the style is underlined, or null if not set
        """
        ...


    def isStrikethrough(self) -> bool:
        """
        Returns whether this style is strikethrough

        Returns
        - whether the style is strikethrough
        """
        ...


    def isStrikethroughRaw(self) -> "Boolean":
        """
        Returns whether this style is strikethrough. May return null.

        Returns
        - whether the style is strikethrough, or null if not set
        """
        ...


    def isObfuscated(self) -> bool:
        """
        Returns whether this style is obfuscated.

        Returns
        - whether the style is obfuscated
        """
        ...


    def isObfuscatedRaw(self) -> "Boolean":
        """
        Returns whether this style is obfuscated. May return null.

        Returns
        - whether the style is obfuscated, or null if not set
        """
        ...


    def isEmpty(self) -> bool:
        """
        Returns whether this style has any formatting explicitly set.

        Returns
        - True if at least one value is set, False if none are set
        """
        ...


    def clone(self) -> "ComponentStyle":
        ...


    @staticmethod
    def builder() -> "ComponentStyleBuilder":
        """
        Get a new ComponentStyleBuilder.

        Returns
        - the builder
        """
        ...


    @staticmethod
    def builder(other: "ComponentStyle") -> "ComponentStyleBuilder":
        """
        Get a new ComponentStyleBuilder with values initialized to the
        style values of the supplied ComponentStyle.

        Arguments
        - other: the component style whose values to copy into the builder

        Returns
        - the builder
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.Vault

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import UUID
from org.bukkit.block import *
from org.bukkit.inventory import ItemStack
from org.bukkit.loot import LootTable
from typing import Any, Callable, Iterable, Tuple


class Vault(TileState):
    """
    Represents a captured state of a vault.
    """

    def getActivationRange(self) -> float:
        """
        Gets the distance at which a player must enter for this vault to
        activate.

        Returns
        - the distance at which a player must enter for this vault
        to activate.
        """
        ...


    def setActivationRange(self, range: float) -> None:
        """
        Sets the distance at which a player must enter for this vault to
        activate.

        Arguments
        - range: the distance at which a player must enter for this
        vault to activate.
        """
        ...


    def getDeactivationRange(self) -> float:
        """
        Gets the distance at which a player must exit for the vault to
        deactivate.

        Returns
        - the distance at which a player must exit for the vault
        to deactivate.
        """
        ...


    def setDeactivationRange(self, range: float) -> None:
        """
        Sets the distance at which a player must exit for this vault to
        deactivate.

        Arguments
        - range: the distance at which a player must exit for this
        vault to deactivate.
        """
        ...


    def getLootTable(self) -> "LootTable":
        """
        Gets the LootTable this vault will pick rewards from.

        Returns
        - the loot table
        """
        ...


    def setLootTable(self, table: "LootTable") -> None:
        """
        Sets the LootTable this vault will pick rewards from.

        Arguments
        - table: the loot table
        """
        ...


    def getDisplayLootTable(self) -> "LootTable":
        """
        Gets the LootTable this vault will display items from. 
        If this value is null the regular loot table will be used to display
        items.

        Returns
        - the loot table to display items from
        """
        ...


    def setDisplayLootTable(self, table: "LootTable") -> None:
        """
        Sets the LootTable this vault will display items from. 
        If this value is set to null the regular loot table will be used to
        display items.

        Arguments
        - table: the loot table to display items from
        """
        ...


    def getKeyItem(self) -> "ItemStack":
        """
        Gets the ItemStack players must use to unlock this vault.

        Returns
        - the key item
        """
        ...


    def setKeyItem(self, keyItem: "ItemStack") -> None:
        """
        Sets the ItemStack players must use to unlock this vault.

        Arguments
        - keyItem: the key item
        """
        ...


    def getRewardedPlayers(self) -> set["UUID"]:
        """
        Gets the players who have already received rewards from this vault.

        Returns
        - unmodifiable set of player UUIDs

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...



"""
Python module generated from Java source file com.google.gson.Strictness

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonWriter
from enum import Enum
from typing import Any, Callable, Iterable, Tuple


class Strictness(Enum):
    """
    Modes that indicate how strictly a JSON JsonReader reader or JsonWriter
    writer follows the syntax laid out in the <a href="https://www.ietf.org/rfc/rfc8259.txt">RFC
    8259 JSON specification</a>.
    
    You can look at JsonReader.setStrictness(Strictness) to see how the strictness affects
    the JsonReader and you can look at JsonWriter.setStrictness(Strictness) to see
    how the strictness affects the JsonWriter.

    See
    - JsonWriter.setStrictness(Strictness)

    Since
    - 2.11.0
    """

    LENIENT = 0
    """
    Allow large deviations from the JSON specification.
    """
    LEGACY_STRICT = 1
    """
    Allow certain small deviations from the JSON specification for legacy reasons.
    """
    STRICT = 2
    """
    Strict compliance with the JSON specification.
    """



"""
Python module generated from Java source file com.google.common.collect.ForwardingCollection

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Iterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingCollection(ForwardingObject, Collection):
    """
    A collection which forwards all its method calls to another collection. Subclasses should
    override one or more methods to modify the behavior of the backing collection as desired per the
    <a href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **Warning:** The methods of `ForwardingCollection` forward **indiscriminately** to
    the methods of the delegate. For example, overriding .add alone **will not** change
    the behavior of .addAll, which can lead to unexpected behavior. In this case, you should
    override `addAll` as well, either providing your own implementation, or delegating to the
    provided `standardAddAll` method.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingCollection`.
    
    The `standard` methods are not guaranteed to be thread-safe, even when all of the
    methods that they depend on are thread-safe.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0
    """

    def iterator(self) -> Iterator["E"]:
        ...


    def size(self) -> int:
        ...


    def removeAll(self, collection: Iterable[Any]) -> bool:
        ...


    def isEmpty(self) -> bool:
        ...


    def contains(self, object: "Object") -> bool:
        ...


    def add(self, element: "E") -> bool:
        ...


    def remove(self, object: "Object") -> bool:
        ...


    def containsAll(self, collection: Iterable[Any]) -> bool:
        ...


    def addAll(self, collection: Iterable["E"]) -> bool:
        ...


    def retainAll(self, collection: Iterable[Any]) -> bool:
        ...


    def clear(self) -> None:
        ...


    def toArray(self) -> list["Object"]:
        ...


    def toArray(self, array: list["T"]) -> list["T"]:
        ...



"""
Python module generated from Java source file org.bukkit.util.BoundingBox

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.util import Objects
from org.bukkit import Location
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import SerializableAs
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class BoundingBox(Cloneable, ConfigurationSerializable):
    """
    A mutable axis aligned bounding box (AABB).
    
    This basically represents a rectangular box (specified by minimum and maximum
    corners) that can for example be used to describe the position and extents of
    an object (such as an entity, block, or rectangular region) in 3D space. Its
    edges and faces are parallel to the axes of the cartesian coordinate system.
    
    The bounding box may be degenerate (one or more sides having the length 0).
    
    Because bounding boxes are mutable, storing them long term may be dangerous
    if they get modified later. If you want to keep around a bounding box, it may
    be wise to call .clone() in order to get a copy.
    """

    def __init__(self):
        """
        Creates a new (degenerate) bounding box with all corner coordinates at
        `0`.
        """
        ...


    def __init__(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float):
        """
        Creates a new bounding box from the given corner coordinates.

        Arguments
        - x1: the first corner's x value
        - y1: the first corner's y value
        - z1: the first corner's z value
        - x2: the second corner's x value
        - y2: the second corner's y value
        - z2: the second corner's z value
        """
        ...


    @staticmethod
    def of(corner1: "Vector", corner2: "Vector") -> "BoundingBox":
        """
        Creates a new bounding box using the coordinates of the given vectors as
        corners.

        Arguments
        - corner1: the first corner
        - corner2: the second corner

        Returns
        - the bounding box
        """
        ...


    @staticmethod
    def of(corner1: "Location", corner2: "Location") -> "BoundingBox":
        """
        Creates a new bounding box using the coordinates of the given locations
        as corners.

        Arguments
        - corner1: the first corner
        - corner2: the second corner

        Returns
        - the bounding box
        """
        ...


    @staticmethod
    def of(corner1: "Block", corner2: "Block") -> "BoundingBox":
        """
        Creates a new bounding box using the coordinates of the given blocks as
        corners.
        
        The bounding box will be sized to fully contain both blocks.

        Arguments
        - corner1: the first corner block
        - corner2: the second corner block

        Returns
        - the bounding box
        """
        ...


    @staticmethod
    def of(block: "Block") -> "BoundingBox":
        """
        Creates a new 1x1x1 sized bounding box containing the given block.

        Arguments
        - block: the block

        Returns
        - the bounding box
        """
        ...


    @staticmethod
    def of(center: "Vector", x: float, y: float, z: float) -> "BoundingBox":
        """
        Creates a new bounding box using the given center and extents.

        Arguments
        - center: the center
        - x: 1/2 the size of the bounding box along the x axis
        - y: 1/2 the size of the bounding box along the y axis
        - z: 1/2 the size of the bounding box along the z axis

        Returns
        - the bounding box
        """
        ...


    @staticmethod
    def of(center: "Location", x: float, y: float, z: float) -> "BoundingBox":
        """
        Creates a new bounding box using the given center and extents.

        Arguments
        - center: the center
        - x: 1/2 the size of the bounding box along the x axis
        - y: 1/2 the size of the bounding box along the y axis
        - z: 1/2 the size of the bounding box along the z axis

        Returns
        - the bounding box
        """
        ...


    def resize(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> "BoundingBox":
        """
        Resizes this bounding box.

        Arguments
        - x1: the first corner's x value
        - y1: the first corner's y value
        - z1: the first corner's z value
        - x2: the second corner's x value
        - y2: the second corner's y value
        - z2: the second corner's z value

        Returns
        - this bounding box (resized)
        """
        ...


    def getMinX(self) -> float:
        """
        Gets the minimum x value.

        Returns
        - the minimum x value
        """
        ...


    def getMinY(self) -> float:
        """
        Gets the minimum y value.

        Returns
        - the minimum y value
        """
        ...


    def getMinZ(self) -> float:
        """
        Gets the minimum z value.

        Returns
        - the minimum z value
        """
        ...


    def getMin(self) -> "Vector":
        """
        Gets the minimum corner as vector.

        Returns
        - the minimum corner as vector
        """
        ...


    def getMaxX(self) -> float:
        """
        Gets the maximum x value.

        Returns
        - the maximum x value
        """
        ...


    def getMaxY(self) -> float:
        """
        Gets the maximum y value.

        Returns
        - the maximum y value
        """
        ...


    def getMaxZ(self) -> float:
        """
        Gets the maximum z value.

        Returns
        - the maximum z value
        """
        ...


    def getMax(self) -> "Vector":
        """
        Gets the maximum corner as vector.

        Returns
        - the maximum corner vector
        """
        ...


    def getWidthX(self) -> float:
        """
        Gets the width of the bounding box in the x direction.

        Returns
        - the width in the x direction
        """
        ...


    def getWidthZ(self) -> float:
        """
        Gets the width of the bounding box in the z direction.

        Returns
        - the width in the z direction
        """
        ...


    def getHeight(self) -> float:
        """
        Gets the height of the bounding box.

        Returns
        - the height
        """
        ...


    def getVolume(self) -> float:
        """
        Gets the volume of the bounding box.

        Returns
        - the volume
        """
        ...


    def getCenterX(self) -> float:
        """
        Gets the x coordinate of the center of the bounding box.

        Returns
        - the center's x coordinate
        """
        ...


    def getCenterY(self) -> float:
        """
        Gets the y coordinate of the center of the bounding box.

        Returns
        - the center's y coordinate
        """
        ...


    def getCenterZ(self) -> float:
        """
        Gets the z coordinate of the center of the bounding box.

        Returns
        - the center's z coordinate
        """
        ...


    def getCenter(self) -> "Vector":
        """
        Gets the center of the bounding box.

        Returns
        - the center
        """
        ...


    def copy(self, other: "BoundingBox") -> "BoundingBox":
        """
        Copies another bounding box.

        Arguments
        - other: the other bounding box

        Returns
        - this bounding box
        """
        ...


    def expand(self, negativeX: float, negativeY: float, negativeZ: float, positiveX: float, positiveY: float, positiveZ: float) -> "BoundingBox":
        """
        Expands this bounding box by the given values in the corresponding
        directions.
        
        Negative values will shrink the bounding box in the corresponding
        direction. Shrinking will be limited to the point where the affected
        opposite faces would meet if the they shrank at uniform speeds.

        Arguments
        - negativeX: the amount of expansion in the negative x direction
        - negativeY: the amount of expansion in the negative y direction
        - negativeZ: the amount of expansion in the negative z direction
        - positiveX: the amount of expansion in the positive x direction
        - positiveY: the amount of expansion in the positive y direction
        - positiveZ: the amount of expansion in the positive z direction

        Returns
        - this bounding box (now expanded)
        """
        ...


    def expand(self, x: float, y: float, z: float) -> "BoundingBox":
        """
        Expands this bounding box uniformly by the given values in both positive
        and negative directions.
        
        Negative values will shrink the bounding box. Shrinking will be limited
        to the bounding box's current size.

        Arguments
        - x: the amount of expansion in both positive and negative x
        direction
        - y: the amount of expansion in both positive and negative y
        direction
        - z: the amount of expansion in both positive and negative z
        direction

        Returns
        - this bounding box (now expanded)
        """
        ...


    def expand(self, expansion: "Vector") -> "BoundingBox":
        """
        Expands this bounding box uniformly by the given values in both positive
        and negative directions.
        
        Negative values will shrink the bounding box. Shrinking will be limited
        to the bounding box's current size.

        Arguments
        - expansion: the expansion values

        Returns
        - this bounding box (now expanded)
        """
        ...


    def expand(self, expansion: float) -> "BoundingBox":
        """
        Expands this bounding box uniformly by the given value in all directions.
        
        A negative value will shrink the bounding box. Shrinking will be limited
        to the bounding box's current size.

        Arguments
        - expansion: the amount of expansion

        Returns
        - this bounding box (now expanded)
        """
        ...


    def expand(self, dirX: float, dirY: float, dirZ: float, expansion: float) -> "BoundingBox":
        """
        Expands this bounding box in the specified direction.
        
        The magnitude of the direction will scale the expansion. A negative
        expansion value will shrink the bounding box in this direction. Shrinking
        will be limited to the bounding box's current size.

        Arguments
        - dirX: the x direction component
        - dirY: the y direction component
        - dirZ: the z direction component
        - expansion: the amount of expansion

        Returns
        - this bounding box (now expanded)
        """
        ...


    def expand(self, direction: "Vector", expansion: float) -> "BoundingBox":
        """
        Expands this bounding box in the specified direction.
        
        The magnitude of the direction will scale the expansion. A negative
        expansion value will shrink the bounding box in this direction. Shrinking
        will be limited to the bounding box's current size.

        Arguments
        - direction: the direction
        - expansion: the amount of expansion

        Returns
        - this bounding box (now expanded)
        """
        ...


    def expand(self, blockFace: "BlockFace", expansion: float) -> "BoundingBox":
        """
        Expands this bounding box in the direction specified by the given block
        face.
        
        A negative expansion value will shrink the bounding box in this
        direction. Shrinking will be limited to the bounding box's current size.

        Arguments
        - blockFace: the block face
        - expansion: the amount of expansion

        Returns
        - this bounding box (now expanded)
        """
        ...


    def expandDirectional(self, dirX: float, dirY: float, dirZ: float) -> "BoundingBox":
        """
        Expands this bounding box in the specified direction.
        
        Negative values will expand the bounding box in the negative direction,
        positive values will expand it in the positive direction. The magnitudes
        of the direction components determine the corresponding amounts of
        expansion.

        Arguments
        - dirX: the x direction component
        - dirY: the y direction component
        - dirZ: the z direction component

        Returns
        - this bounding box (now expanded)
        """
        ...


    def expandDirectional(self, direction: "Vector") -> "BoundingBox":
        """
        Expands this bounding box in the specified direction.
        
        Negative values will expand the bounding box in the negative direction,
        positive values will expand it in the positive direction. The magnitude
        of the direction vector determines the amount of expansion.

        Arguments
        - direction: the direction and magnitude of the expansion

        Returns
        - this bounding box (now expanded)
        """
        ...


    def union(self, posX: float, posY: float, posZ: float) -> "BoundingBox":
        """
        Expands this bounding box to contain (or border) the specified position.

        Arguments
        - posX: the x position value
        - posY: the y position value
        - posZ: the z position value

        Returns
        - this bounding box (now expanded)

        See
        - .contains(double, double, double)
        """
        ...


    def union(self, position: "Vector") -> "BoundingBox":
        """
        Expands this bounding box to contain (or border) the specified position.

        Arguments
        - position: the position

        Returns
        - this bounding box (now expanded)

        See
        - .contains(double, double, double)
        """
        ...


    def union(self, position: "Location") -> "BoundingBox":
        """
        Expands this bounding box to contain (or border) the specified position.

        Arguments
        - position: the position

        Returns
        - this bounding box (now expanded)

        See
        - .contains(double, double, double)
        """
        ...


    def union(self, other: "BoundingBox") -> "BoundingBox":
        """
        Expands this bounding box to contain both this and the given bounding
        box.

        Arguments
        - other: the other bounding box

        Returns
        - this bounding box (now expanded)
        """
        ...


    def intersection(self, other: "BoundingBox") -> "BoundingBox":
        """
        Resizes this bounding box to represent the intersection of this and the
        given bounding box.

        Arguments
        - other: the other bounding box

        Returns
        - this bounding box (now representing the intersection)

        Raises
        - IllegalArgumentException: if the bounding boxes don't overlap
        """
        ...


    def shift(self, shiftX: float, shiftY: float, shiftZ: float) -> "BoundingBox":
        """
        Shifts this bounding box by the given amounts.

        Arguments
        - shiftX: the shift in x direction
        - shiftY: the shift in y direction
        - shiftZ: the shift in z direction

        Returns
        - this bounding box (now shifted)
        """
        ...


    def shift(self, shift: "Vector") -> "BoundingBox":
        """
        Shifts this bounding box by the given amounts.

        Arguments
        - shift: the shift

        Returns
        - this bounding box (now shifted)
        """
        ...


    def shift(self, shift: "Location") -> "BoundingBox":
        """
        Shifts this bounding box by the given amounts.

        Arguments
        - shift: the shift

        Returns
        - this bounding box (now shifted)
        """
        ...


    def overlaps(self, other: "BoundingBox") -> bool:
        """
        Checks if this bounding box overlaps with the given bounding box.
        
        Bounding boxes that are only intersecting at the borders are not
        considered overlapping.

        Arguments
        - other: the other bounding box

        Returns
        - `True` if overlapping
        """
        ...


    def overlaps(self, min: "Vector", max: "Vector") -> bool:
        """
        Checks if this bounding box overlaps with the bounding box that is
        defined by the given corners.
        
        Bounding boxes that are only intersecting at the borders are not
        considered overlapping.

        Arguments
        - min: the first corner
        - max: the second corner

        Returns
        - `True` if overlapping
        """
        ...


    def contains(self, x: float, y: float, z: float) -> bool:
        """
        Checks if this bounding box contains the specified position.
        
        Positions exactly on the minimum borders of the bounding box are
        considered to be inside the bounding box, while positions exactly on the
        maximum borders are considered to be outside. This allows bounding boxes
        to reside directly next to each other with positions always only residing
        in exactly one of them.

        Arguments
        - x: the position's x coordinates
        - y: the position's y coordinates
        - z: the position's z coordinates

        Returns
        - `True` if the bounding box contains the position
        """
        ...


    def contains(self, position: "Vector") -> bool:
        """
        Checks if this bounding box contains the specified position.
        
        Positions exactly on the minimum borders of the bounding box are
        considered to be inside the bounding box, while positions exactly on the
        maximum borders are considered to be outside. This allows bounding boxes
        to reside directly next to each other with positions always only residing
        in exactly one of them.

        Arguments
        - position: the position

        Returns
        - `True` if the bounding box contains the position
        """
        ...


    def contains(self, other: "BoundingBox") -> bool:
        """
        Checks if this bounding box fully contains the given bounding box.

        Arguments
        - other: the other bounding box

        Returns
        - `True` if the bounding box contains the given bounding
        box
        """
        ...


    def contains(self, min: "Vector", max: "Vector") -> bool:
        """
        Checks if this bounding box fully contains the bounding box that is
        defined by the given corners.

        Arguments
        - min: the first corner
        - max: the second corner

        Returns
        - `True` if the bounding box contains the specified
            bounding box
        """
        ...


    def rayTrace(self, start: "Vector", direction: "Vector", maxDistance: float) -> "RayTraceResult":
        """
        Calculates the intersection of this bounding box with the specified line
        segment.
        
        Intersections at edges and corners yield one of the affected block faces
        as hit result, but it is not defined which of them.

        Arguments
        - start: the start position
        - direction: the ray direction
        - maxDistance: the maximum distance

        Returns
        - the ray trace hit result, or `null` if there is no hit
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "BoundingBox":
        """
        Creates a copy of this bounding box.

        Returns
        - the cloned bounding box
        """
        ...


    def serialize(self) -> dict[str, "Object"]:
        ...


    @staticmethod
    def deserialize(args: dict[str, "Object"]) -> "BoundingBox":
        ...



"""
Python module generated from Java source file java.util.UUID

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.security import *
from java.util import *
from jdk.internal.access import JavaLangAccess
from jdk.internal.access import SharedSecrets
from typing import Any, Callable, Iterable, Tuple


class UUID(Serializable, Comparable):
    """
    A class that represents an immutable universally unique identifier (UUID).
    A UUID represents a 128-bit value.
    
     There exist different variants of these global identifiers.  The methods
    of this class are for manipulating the Leach-Salz variant, although the
    constructors allow the creation of any variant of UUID (described below).
    
     The layout of a variant 2 (Leach-Salz) UUID is as follows:
    
    The most significant long consists of the following unsigned fields:
    ```
    0xFFFFFFFF00000000 time_low
    0x00000000FFFF0000 time_mid
    0x000000000000F000 version
    0x0000000000000FFF time_hi
    ```
    The least significant long consists of the following unsigned fields:
    ```
    0xC000000000000000 variant
    0x3FFF000000000000 clock_seq
    0x0000FFFFFFFFFFFF node
    ```
    
     The variant field contains a value which identifies the layout of the
    `UUID`.  The bit layout described above is valid only for a `UUID` with a variant value of 2, which indicates the Leach-Salz variant.
    
     The version field holds a value that describes the type of this `UUID`.  There are four different basic types of UUIDs: time-based, DCE
    security, name-based, and randomly generated UUIDs.  These types have a
    version value of 1, 2, 3 and 4, respectively.
    
     For more information including algorithms used to create `UUID`s,
    see <a href="http://www.ietf.org/rfc/rfc4122.txt"> *RFC&nbsp;4122: A
    Universally Unique IDentifier (UUID) URN Namespace*</a>, section 4.2
    &quot;Algorithms for Creating a Time-Based UUID&quot;.

    Since
    - 1.5
    """

    def __init__(self, mostSigBits: int, leastSigBits: int):
        """
        Constructs a new `UUID` using the specified data.  `mostSigBits` is used for the most significant 64 bits of the `UUID` and `leastSigBits` becomes the least significant 64 bits of
        the `UUID`.

        Arguments
        - mostSigBits: The most significant bits of the `UUID`
        - leastSigBits: The least significant bits of the `UUID`
        """
        ...


    @staticmethod
    def randomUUID() -> "UUID":
        """
        Static factory to retrieve a type 4 (pseudo randomly generated) UUID.
        
        The `UUID` is generated using a cryptographically strong pseudo
        random number generator.

        Returns
        - A randomly generated `UUID`
        """
        ...


    @staticmethod
    def nameUUIDFromBytes(name: list[int]) -> "UUID":
        """
        Static factory to retrieve a type 3 (name based) `UUID` based on
        the specified byte array.

        Arguments
        - name: A byte array to be used to construct a `UUID`

        Returns
        - A `UUID` generated from the specified array
        """
        ...


    @staticmethod
    def fromString(name: str) -> "UUID":
        """
        Creates a `UUID` from the string standard representation as
        described in the .toString method.

        Arguments
        - name: A string that specifies a `UUID`

        Returns
        - A `UUID` with the specified value

        Raises
        - IllegalArgumentException: If name does not conform to the string representation as
                 described in .toString
        """
        ...


    def getLeastSignificantBits(self) -> int:
        """
        Returns the least significant 64 bits of this UUID's 128 bit value.

        Returns
        - The least significant 64 bits of this UUID's 128 bit value
        """
        ...


    def getMostSignificantBits(self) -> int:
        """
        Returns the most significant 64 bits of this UUID's 128 bit value.

        Returns
        - The most significant 64 bits of this UUID's 128 bit value
        """
        ...


    def version(self) -> int:
        """
        The version number associated with this `UUID`.  The version
        number describes how this `UUID` was generated.
        
        The version number has the following meaning:
        
        - 1    Time-based UUID
        - 2    DCE security UUID
        - 3    Name-based UUID
        - 4    Randomly generated UUID

        Returns
        - The version number of this `UUID`
        """
        ...


    def variant(self) -> int:
        """
        The variant number associated with this `UUID`.  The variant
        number describes the layout of the `UUID`.
        
        The variant number has the following meaning:
        
        - 0    Reserved for NCS backward compatibility
        - 2    <a href="http://www.ietf.org/rfc/rfc4122.txt">IETF&nbsp;RFC&nbsp;4122</a>
        (Leach-Salz), used by this class
        - 6    Reserved, Microsoft Corporation backward compatibility
        - 7    Reserved for future definition

        Returns
        - The variant number of this `UUID`
        """
        ...


    def timestamp(self) -> int:
        """
        The timestamp value associated with this UUID.
        
         The 60 bit timestamp value is constructed from the time_low,
        time_mid, and time_hi fields of this `UUID`.  The resulting
        timestamp is measured in 100-nanosecond units since midnight,
        October 15, 1582 UTC.
        
         The timestamp value is only meaningful in a time-based UUID, which
        has version type 1.  If this `UUID` is not a time-based UUID then
        this method throws UnsupportedOperationException.

        Returns
        - The timestamp of this `UUID`.

        Raises
        - UnsupportedOperationException: If this UUID is not a version 1 UUID
        """
        ...


    def clockSequence(self) -> int:
        """
        The clock sequence value associated with this UUID.
        
         The 14 bit clock sequence value is constructed from the clock
        sequence field of this UUID.  The clock sequence field is used to
        guarantee temporal uniqueness in a time-based UUID.
        
         The `clockSequence` value is only meaningful in a time-based
        UUID, which has version type 1.  If this UUID is not a time-based UUID
        then this method throws UnsupportedOperationException.

        Returns
        - The clock sequence of this `UUID`

        Raises
        - UnsupportedOperationException: If this UUID is not a version 1 UUID
        """
        ...


    def node(self) -> int:
        """
        The node value associated with this UUID.
        
         The 48 bit node value is constructed from the node field of this
        UUID.  This field is intended to hold the IEEE 802 address of the machine
        that generated this UUID to guarantee spatial uniqueness.
        
         The node value is only meaningful in a time-based UUID, which has
        version type 1.  If this UUID is not a time-based UUID then this method
        throws UnsupportedOperationException.

        Returns
        - The node value of this `UUID`

        Raises
        - UnsupportedOperationException: If this UUID is not a version 1 UUID
        """
        ...


    def toString(self) -> str:
        """
        Returns a `String` object representing this `UUID`.
        
         The UUID string representation is as described by this BNF:
        <blockquote>```
        `UUID                   = <time_low> "-" <time_mid> "-"
                                 <time_high_and_version> "-"
                                 <variant_and_sequence> "-"
                                 <node>
        time_low               = 4*<hexOctet>
        time_mid               = 2*<hexOctet>
        time_high_and_version  = 2*<hexOctet>
        variant_and_sequence   = 2*<hexOctet>
        node                   = 6*<hexOctet>
        hexOctet               = <hexDigit><hexDigit>
        hexDigit               =
              "0" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9"
              | "a" | "b" | "c" | "d" | "e" | "f"
              | "A" | "B" | "C" | "D" | "E" | "F"````</blockquote>

        Returns
        - A string representation of this `UUID`
        """
        ...


    def hashCode(self) -> int:
        """
        Returns a hash code for this `UUID`.

        Returns
        - A hash code value for this `UUID`
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares this object to the specified object.  The result is `True` if and only if the argument is not `null`, is a `UUID`
        object, has the same variant, and contains the same value, bit for bit,
        as this `UUID`.

        Arguments
        - obj: The object to be compared

        Returns
        - `True` if the objects are the same; `False`
                 otherwise
        """
        ...


    def compareTo(self, val: "UUID") -> int:
        """
        Compares this UUID with the specified UUID.
        
         The first of two UUIDs is greater than the second if the most
        significant field in which the UUIDs differ is greater for the first
        UUID.

        Arguments
        - val: `UUID` to which this `UUID` is to be compared

        Returns
        - -1, 0 or 1 as this `UUID` is less than, equal to, or
                 greater than `val`
        """
        ...
